'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_VERSION_GL_1_0'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_VERSION_GL_1_0',error_checker=_errors._error_checker)
GL_2D=_C('GL_2D',0x0600)
GL_2_BYTES=_C('GL_2_BYTES',0x1407)
GL_3D=_C('GL_3D',0x0601)
GL_3D_COLOR=_C('GL_3D_COLOR',0x0602)
GL_3D_COLOR_TEXTURE=_C('GL_3D_COLOR_TEXTURE',0x0603)
GL_3_BYTES=_C('GL_3_BYTES',0x1408)
GL_4D_COLOR_TEXTURE=_C('GL_4D_COLOR_TEXTURE',0x0604)
GL_4_BYTES=_C('GL_4_BYTES',0x1409)
GL_ACCUM=_C('GL_ACCUM',0x0100)
GL_ACCUM_ALPHA_BITS=_C('GL_ACCUM_ALPHA_BITS',0x0D5B)
GL_ACCUM_BLUE_BITS=_C('GL_ACCUM_BLUE_BITS',0x0D5A)
GL_ACCUM_BUFFER_BIT=_C('GL_ACCUM_BUFFER_BIT',0x00000200)
GL_ACCUM_CLEAR_VALUE=_C('GL_ACCUM_CLEAR_VALUE',0x0B80)
GL_ACCUM_GREEN_BITS=_C('GL_ACCUM_GREEN_BITS',0x0D59)
GL_ACCUM_RED_BITS=_C('GL_ACCUM_RED_BITS',0x0D58)
GL_ADD=_C('GL_ADD',0x0104)
GL_ALL_ATTRIB_BITS=_C('GL_ALL_ATTRIB_BITS',0xFFFFFFFF)
GL_ALPHA=_C('GL_ALPHA',0x1906)
GL_ALPHA_BIAS=_C('GL_ALPHA_BIAS',0x0D1D)
GL_ALPHA_BITS=_C('GL_ALPHA_BITS',0x0D55)
GL_ALPHA_SCALE=_C('GL_ALPHA_SCALE',0x0D1C)
GL_ALPHA_TEST=_C('GL_ALPHA_TEST',0x0BC0)
GL_ALPHA_TEST_FUNC=_C('GL_ALPHA_TEST_FUNC',0x0BC1)
GL_ALPHA_TEST_REF=_C('GL_ALPHA_TEST_REF',0x0BC2)
GL_ALWAYS=_C('GL_ALWAYS',0x0207)
GL_AMBIENT=_C('GL_AMBIENT',0x1200)
GL_AMBIENT_AND_DIFFUSE=_C('GL_AMBIENT_AND_DIFFUSE',0x1602)
GL_AND=_C('GL_AND',0x1501)
GL_AND_INVERTED=_C('GL_AND_INVERTED',0x1504)
GL_AND_REVERSE=_C('GL_AND_REVERSE',0x1502)
GL_ATTRIB_STACK_DEPTH=_C('GL_ATTRIB_STACK_DEPTH',0x0BB0)
GL_AUTO_NORMAL=_C('GL_AUTO_NORMAL',0x0D80)
GL_AUX0=_C('GL_AUX0',0x0409)
GL_AUX1=_C('GL_AUX1',0x040A)
GL_AUX2=_C('GL_AUX2',0x040B)
GL_AUX3=_C('GL_AUX3',0x040C)
GL_AUX_BUFFERS=_C('GL_AUX_BUFFERS',0x0C00)
GL_BACK=_C('GL_BACK',0x0405)
GL_BACK_LEFT=_C('GL_BACK_LEFT',0x0402)
GL_BACK_RIGHT=_C('GL_BACK_RIGHT',0x0403)
GL_BITMAP=_C('GL_BITMAP',0x1A00)
GL_BITMAP_TOKEN=_C('GL_BITMAP_TOKEN',0x0704)
GL_BLEND=_C('GL_BLEND',0x0BE2)
GL_BLEND_DST=_C('GL_BLEND_DST',0x0BE0)
GL_BLEND_SRC=_C('GL_BLEND_SRC',0x0BE1)
GL_BLUE=_C('GL_BLUE',0x1905)
GL_BLUE_BIAS=_C('GL_BLUE_BIAS',0x0D1B)
GL_BLUE_BITS=_C('GL_BLUE_BITS',0x0D54)
GL_BLUE_SCALE=_C('GL_BLUE_SCALE',0x0D1A)
GL_BYTE=_C('GL_BYTE',0x1400)
GL_CCW=_C('GL_CCW',0x0901)
GL_CLAMP=_C('GL_CLAMP',0x2900)
GL_CLEAR=_C('GL_CLEAR',0x1500)
GL_CLIP_PLANE0=_C('GL_CLIP_PLANE0',0x3000)
GL_CLIP_PLANE1=_C('GL_CLIP_PLANE1',0x3001)
GL_CLIP_PLANE2=_C('GL_CLIP_PLANE2',0x3002)
GL_CLIP_PLANE3=_C('GL_CLIP_PLANE3',0x3003)
GL_CLIP_PLANE4=_C('GL_CLIP_PLANE4',0x3004)
GL_CLIP_PLANE5=_C('GL_CLIP_PLANE5',0x3005)
GL_COEFF=_C('GL_COEFF',0x0A00)
GL_COLOR=_C('GL_COLOR',0x1800)
GL_COLOR_BUFFER_BIT=_C('GL_COLOR_BUFFER_BIT',0x00004000)
GL_COLOR_CLEAR_VALUE=_C('GL_COLOR_CLEAR_VALUE',0x0C22)
GL_COLOR_INDEX=_C('GL_COLOR_INDEX',0x1900)
GL_COLOR_INDEXES=_C('GL_COLOR_INDEXES',0x1603)
GL_COLOR_MATERIAL=_C('GL_COLOR_MATERIAL',0x0B57)
GL_COLOR_MATERIAL_FACE=_C('GL_COLOR_MATERIAL_FACE',0x0B55)
GL_COLOR_MATERIAL_PARAMETER=_C('GL_COLOR_MATERIAL_PARAMETER',0x0B56)
GL_COLOR_WRITEMASK=_C('GL_COLOR_WRITEMASK',0x0C23)
GL_COMPILE=_C('GL_COMPILE',0x1300)
GL_COMPILE_AND_EXECUTE=_C('GL_COMPILE_AND_EXECUTE',0x1301)
GL_CONSTANT_ATTENUATION=_C('GL_CONSTANT_ATTENUATION',0x1207)
GL_COPY=_C('GL_COPY',0x1503)
GL_COPY_INVERTED=_C('GL_COPY_INVERTED',0x150C)
GL_COPY_PIXEL_TOKEN=_C('GL_COPY_PIXEL_TOKEN',0x0706)
GL_CULL_FACE=_C('GL_CULL_FACE',0x0B44)
GL_CULL_FACE_MODE=_C('GL_CULL_FACE_MODE',0x0B45)
GL_CURRENT_BIT=_C('GL_CURRENT_BIT',0x00000001)
GL_CURRENT_COLOR=_C('GL_CURRENT_COLOR',0x0B00)
GL_CURRENT_INDEX=_C('GL_CURRENT_INDEX',0x0B01)
GL_CURRENT_NORMAL=_C('GL_CURRENT_NORMAL',0x0B02)
GL_CURRENT_RASTER_COLOR=_C('GL_CURRENT_RASTER_COLOR',0x0B04)
GL_CURRENT_RASTER_DISTANCE=_C('GL_CURRENT_RASTER_DISTANCE',0x0B09)
GL_CURRENT_RASTER_INDEX=_C('GL_CURRENT_RASTER_INDEX',0x0B05)
GL_CURRENT_RASTER_POSITION=_C('GL_CURRENT_RASTER_POSITION',0x0B07)
GL_CURRENT_RASTER_POSITION_VALID=_C('GL_CURRENT_RASTER_POSITION_VALID',0x0B08)
GL_CURRENT_RASTER_TEXTURE_COORDS=_C('GL_CURRENT_RASTER_TEXTURE_COORDS',0x0B06)
GL_CURRENT_TEXTURE_COORDS=_C('GL_CURRENT_TEXTURE_COORDS',0x0B03)
GL_CW=_C('GL_CW',0x0900)
GL_DECAL=_C('GL_DECAL',0x2101)
GL_DECR=_C('GL_DECR',0x1E03)
GL_DEPTH=_C('GL_DEPTH',0x1801)
GL_DEPTH_BIAS=_C('GL_DEPTH_BIAS',0x0D1F)
GL_DEPTH_BITS=_C('GL_DEPTH_BITS',0x0D56)
GL_DEPTH_BUFFER_BIT=_C('GL_DEPTH_BUFFER_BIT',0x00000100)
GL_DEPTH_CLEAR_VALUE=_C('GL_DEPTH_CLEAR_VALUE',0x0B73)
GL_DEPTH_COMPONENT=_C('GL_DEPTH_COMPONENT',0x1902)
GL_DEPTH_FUNC=_C('GL_DEPTH_FUNC',0x0B74)
GL_DEPTH_RANGE=_C('GL_DEPTH_RANGE',0x0B70)
GL_DEPTH_SCALE=_C('GL_DEPTH_SCALE',0x0D1E)
GL_DEPTH_TEST=_C('GL_DEPTH_TEST',0x0B71)
GL_DEPTH_WRITEMASK=_C('GL_DEPTH_WRITEMASK',0x0B72)
GL_DIFFUSE=_C('GL_DIFFUSE',0x1201)
GL_DITHER=_C('GL_DITHER',0x0BD0)
GL_DOMAIN=_C('GL_DOMAIN',0x0A02)
GL_DONT_CARE=_C('GL_DONT_CARE',0x1100)
GL_DOUBLEBUFFER=_C('GL_DOUBLEBUFFER',0x0C32)
GL_DRAW_BUFFER=_C('GL_DRAW_BUFFER',0x0C01)
GL_DRAW_PIXEL_TOKEN=_C('GL_DRAW_PIXEL_TOKEN',0x0705)
GL_DST_ALPHA=_C('GL_DST_ALPHA',0x0304)
GL_DST_COLOR=_C('GL_DST_COLOR',0x0306)
GL_EDGE_FLAG=_C('GL_EDGE_FLAG',0x0B43)
GL_EMISSION=_C('GL_EMISSION',0x1600)
GL_ENABLE_BIT=_C('GL_ENABLE_BIT',0x00002000)
GL_EQUAL=_C('GL_EQUAL',0x0202)
GL_EQUIV=_C('GL_EQUIV',0x1509)
GL_EVAL_BIT=_C('GL_EVAL_BIT',0x00010000)
GL_EXP=_C('GL_EXP',0x0800)
GL_EXP2=_C('GL_EXP2',0x0801)
GL_EXTENSIONS=_C('GL_EXTENSIONS',0x1F03)
GL_EYE_LINEAR=_C('GL_EYE_LINEAR',0x2400)
GL_EYE_PLANE=_C('GL_EYE_PLANE',0x2502)
GL_FALSE=_C('GL_FALSE',0)
GL_FASTEST=_C('GL_FASTEST',0x1101)
GL_FEEDBACK=_C('GL_FEEDBACK',0x1C01)
GL_FILL=_C('GL_FILL',0x1B02)
GL_FLAT=_C('GL_FLAT',0x1D00)
GL_FLOAT=_C('GL_FLOAT',0x1406)
GL_FOG=_C('GL_FOG',0x0B60)
GL_FOG_BIT=_C('GL_FOG_BIT',0x00000080)
GL_FOG_COLOR=_C('GL_FOG_COLOR',0x0B66)
GL_FOG_DENSITY=_C('GL_FOG_DENSITY',0x0B62)
GL_FOG_END=_C('GL_FOG_END',0x0B64)
GL_FOG_HINT=_C('GL_FOG_HINT',0x0C54)
GL_FOG_INDEX=_C('GL_FOG_INDEX',0x0B61)
GL_FOG_MODE=_C('GL_FOG_MODE',0x0B65)
GL_FOG_START=_C('GL_FOG_START',0x0B63)
GL_FRONT=_C('GL_FRONT',0x0404)
GL_FRONT_AND_BACK=_C('GL_FRONT_AND_BACK',0x0408)
GL_FRONT_FACE=_C('GL_FRONT_FACE',0x0B46)
GL_FRONT_LEFT=_C('GL_FRONT_LEFT',0x0400)
GL_FRONT_RIGHT=_C('GL_FRONT_RIGHT',0x0401)
GL_GEQUAL=_C('GL_GEQUAL',0x0206)
GL_GREATER=_C('GL_GREATER',0x0204)
GL_GREEN=_C('GL_GREEN',0x1904)
GL_GREEN_BIAS=_C('GL_GREEN_BIAS',0x0D19)
GL_GREEN_BITS=_C('GL_GREEN_BITS',0x0D53)
GL_GREEN_SCALE=_C('GL_GREEN_SCALE',0x0D18)
GL_HINT_BIT=_C('GL_HINT_BIT',0x00008000)
GL_INCR=_C('GL_INCR',0x1E02)
GL_INDEX_BITS=_C('GL_INDEX_BITS',0x0D51)
GL_INDEX_CLEAR_VALUE=_C('GL_INDEX_CLEAR_VALUE',0x0C20)
GL_INDEX_MODE=_C('GL_INDEX_MODE',0x0C30)
GL_INDEX_OFFSET=_C('GL_INDEX_OFFSET',0x0D13)
GL_INDEX_SHIFT=_C('GL_INDEX_SHIFT',0x0D12)
GL_INDEX_WRITEMASK=_C('GL_INDEX_WRITEMASK',0x0C21)
GL_INT=_C('GL_INT',0x1404)
GL_INVALID_ENUM=_C('GL_INVALID_ENUM',0x0500)
GL_INVALID_OPERATION=_C('GL_INVALID_OPERATION',0x0502)
GL_INVALID_VALUE=_C('GL_INVALID_VALUE',0x0501)
GL_INVERT=_C('GL_INVERT',0x150A)
GL_KEEP=_C('GL_KEEP',0x1E00)
GL_LEFT=_C('GL_LEFT',0x0406)
GL_LEQUAL=_C('GL_LEQUAL',0x0203)
GL_LESS=_C('GL_LESS',0x0201)
GL_LIGHT0=_C('GL_LIGHT0',0x4000)
GL_LIGHT1=_C('GL_LIGHT1',0x4001)
GL_LIGHT2=_C('GL_LIGHT2',0x4002)
GL_LIGHT3=_C('GL_LIGHT3',0x4003)
GL_LIGHT4=_C('GL_LIGHT4',0x4004)
GL_LIGHT5=_C('GL_LIGHT5',0x4005)
GL_LIGHT6=_C('GL_LIGHT6',0x4006)
GL_LIGHT7=_C('GL_LIGHT7',0x4007)
GL_LIGHTING=_C('GL_LIGHTING',0x0B50)
GL_LIGHTING_BIT=_C('GL_LIGHTING_BIT',0x00000040)
GL_LIGHT_MODEL_AMBIENT=_C('GL_LIGHT_MODEL_AMBIENT',0x0B53)
GL_LIGHT_MODEL_LOCAL_VIEWER=_C('GL_LIGHT_MODEL_LOCAL_VIEWER',0x0B51)
GL_LIGHT_MODEL_TWO_SIDE=_C('GL_LIGHT_MODEL_TWO_SIDE',0x0B52)
GL_LINE=_C('GL_LINE',0x1B01)
GL_LINEAR=_C('GL_LINEAR',0x2601)
GL_LINEAR_ATTENUATION=_C('GL_LINEAR_ATTENUATION',0x1208)
GL_LINEAR_MIPMAP_LINEAR=_C('GL_LINEAR_MIPMAP_LINEAR',0x2703)
GL_LINEAR_MIPMAP_NEAREST=_C('GL_LINEAR_MIPMAP_NEAREST',0x2701)
GL_LINES=_C('GL_LINES',0x0001)
GL_LINE_BIT=_C('GL_LINE_BIT',0x00000004)
GL_LINE_LOOP=_C('GL_LINE_LOOP',0x0002)
GL_LINE_RESET_TOKEN=_C('GL_LINE_RESET_TOKEN',0x0707)
GL_LINE_SMOOTH=_C('GL_LINE_SMOOTH',0x0B20)
GL_LINE_SMOOTH_HINT=_C('GL_LINE_SMOOTH_HINT',0x0C52)
GL_LINE_STIPPLE=_C('GL_LINE_STIPPLE',0x0B24)
GL_LINE_STIPPLE_PATTERN=_C('GL_LINE_STIPPLE_PATTERN',0x0B25)
GL_LINE_STIPPLE_REPEAT=_C('GL_LINE_STIPPLE_REPEAT',0x0B26)
GL_LINE_STRIP=_C('GL_LINE_STRIP',0x0003)
GL_LINE_TOKEN=_C('GL_LINE_TOKEN',0x0702)
GL_LINE_WIDTH=_C('GL_LINE_WIDTH',0x0B21)
GL_LINE_WIDTH_GRANULARITY=_C('GL_LINE_WIDTH_GRANULARITY',0x0B23)
GL_LINE_WIDTH_RANGE=_C('GL_LINE_WIDTH_RANGE',0x0B22)
GL_LIST_BASE=_C('GL_LIST_BASE',0x0B32)
GL_LIST_BIT=_C('GL_LIST_BIT',0x00020000)
GL_LIST_INDEX=_C('GL_LIST_INDEX',0x0B33)
GL_LIST_MODE=_C('GL_LIST_MODE',0x0B30)
GL_LOAD=_C('GL_LOAD',0x0101)
GL_LOGIC_OP=_C('GL_LOGIC_OP',0x0BF1)
GL_LOGIC_OP_MODE=_C('GL_LOGIC_OP_MODE',0x0BF0)
GL_LUMINANCE=_C('GL_LUMINANCE',0x1909)
GL_LUMINANCE_ALPHA=_C('GL_LUMINANCE_ALPHA',0x190A)
GL_MAP1_COLOR_4=_C('GL_MAP1_COLOR_4',0x0D90)
GL_MAP1_GRID_DOMAIN=_C('GL_MAP1_GRID_DOMAIN',0x0DD0)
GL_MAP1_GRID_SEGMENTS=_C('GL_MAP1_GRID_SEGMENTS',0x0DD1)
GL_MAP1_INDEX=_C('GL_MAP1_INDEX',0x0D91)
GL_MAP1_NORMAL=_C('GL_MAP1_NORMAL',0x0D92)
GL_MAP1_TEXTURE_COORD_1=_C('GL_MAP1_TEXTURE_COORD_1',0x0D93)
GL_MAP1_TEXTURE_COORD_2=_C('GL_MAP1_TEXTURE_COORD_2',0x0D94)
GL_MAP1_TEXTURE_COORD_3=_C('GL_MAP1_TEXTURE_COORD_3',0x0D95)
GL_MAP1_TEXTURE_COORD_4=_C('GL_MAP1_TEXTURE_COORD_4',0x0D96)
GL_MAP1_VERTEX_3=_C('GL_MAP1_VERTEX_3',0x0D97)
GL_MAP1_VERTEX_4=_C('GL_MAP1_VERTEX_4',0x0D98)
GL_MAP2_COLOR_4=_C('GL_MAP2_COLOR_4',0x0DB0)
GL_MAP2_GRID_DOMAIN=_C('GL_MAP2_GRID_DOMAIN',0x0DD2)
GL_MAP2_GRID_SEGMENTS=_C('GL_MAP2_GRID_SEGMENTS',0x0DD3)
GL_MAP2_INDEX=_C('GL_MAP2_INDEX',0x0DB1)
GL_MAP2_NORMAL=_C('GL_MAP2_NORMAL',0x0DB2)
GL_MAP2_TEXTURE_COORD_1=_C('GL_MAP2_TEXTURE_COORD_1',0x0DB3)
GL_MAP2_TEXTURE_COORD_2=_C('GL_MAP2_TEXTURE_COORD_2',0x0DB4)
GL_MAP2_TEXTURE_COORD_3=_C('GL_MAP2_TEXTURE_COORD_3',0x0DB5)
GL_MAP2_TEXTURE_COORD_4=_C('GL_MAP2_TEXTURE_COORD_4',0x0DB6)
GL_MAP2_VERTEX_3=_C('GL_MAP2_VERTEX_3',0x0DB7)
GL_MAP2_VERTEX_4=_C('GL_MAP2_VERTEX_4',0x0DB8)
GL_MAP_COLOR=_C('GL_MAP_COLOR',0x0D10)
GL_MAP_STENCIL=_C('GL_MAP_STENCIL',0x0D11)
GL_MATRIX_MODE=_C('GL_MATRIX_MODE',0x0BA0)
GL_MAX_ATTRIB_STACK_DEPTH=_C('GL_MAX_ATTRIB_STACK_DEPTH',0x0D35)
GL_MAX_CLIP_PLANES=_C('GL_MAX_CLIP_PLANES',0x0D32)
GL_MAX_EVAL_ORDER=_C('GL_MAX_EVAL_ORDER',0x0D30)
GL_MAX_LIGHTS=_C('GL_MAX_LIGHTS',0x0D31)
GL_MAX_LIST_NESTING=_C('GL_MAX_LIST_NESTING',0x0B31)
GL_MAX_MODELVIEW_STACK_DEPTH=_C('GL_MAX_MODELVIEW_STACK_DEPTH',0x0D36)
GL_MAX_NAME_STACK_DEPTH=_C('GL_MAX_NAME_STACK_DEPTH',0x0D37)
GL_MAX_PIXEL_MAP_TABLE=_C('GL_MAX_PIXEL_MAP_TABLE',0x0D34)
GL_MAX_PROJECTION_STACK_DEPTH=_C('GL_MAX_PROJECTION_STACK_DEPTH',0x0D38)
GL_MAX_TEXTURE_SIZE=_C('GL_MAX_TEXTURE_SIZE',0x0D33)
GL_MAX_TEXTURE_STACK_DEPTH=_C('GL_MAX_TEXTURE_STACK_DEPTH',0x0D39)
GL_MAX_VIEWPORT_DIMS=_C('GL_MAX_VIEWPORT_DIMS',0x0D3A)
GL_MODELVIEW=_C('GL_MODELVIEW',0x1700)
GL_MODELVIEW_MATRIX=_C('GL_MODELVIEW_MATRIX',0x0BA6)
GL_MODELVIEW_STACK_DEPTH=_C('GL_MODELVIEW_STACK_DEPTH',0x0BA3)
GL_MODULATE=_C('GL_MODULATE',0x2100)
GL_MULT=_C('GL_MULT',0x0103)
GL_NAME_STACK_DEPTH=_C('GL_NAME_STACK_DEPTH',0x0D70)
GL_NAND=_C('GL_NAND',0x150E)
GL_NEAREST=_C('GL_NEAREST',0x2600)
GL_NEAREST_MIPMAP_LINEAR=_C('GL_NEAREST_MIPMAP_LINEAR',0x2702)
GL_NEAREST_MIPMAP_NEAREST=_C('GL_NEAREST_MIPMAP_NEAREST',0x2700)
GL_NEVER=_C('GL_NEVER',0x0200)
GL_NICEST=_C('GL_NICEST',0x1102)
GL_NONE=_C('GL_NONE',0)
GL_NOOP=_C('GL_NOOP',0x1505)
GL_NOR=_C('GL_NOR',0x1508)
GL_NORMALIZE=_C('GL_NORMALIZE',0x0BA1)
GL_NOTEQUAL=_C('GL_NOTEQUAL',0x0205)
GL_NO_ERROR=_C('GL_NO_ERROR',0)
GL_OBJECT_LINEAR=_C('GL_OBJECT_LINEAR',0x2401)
GL_OBJECT_PLANE=_C('GL_OBJECT_PLANE',0x2501)
GL_ONE=_C('GL_ONE',1)
GL_ONE_MINUS_DST_ALPHA=_C('GL_ONE_MINUS_DST_ALPHA',0x0305)
GL_ONE_MINUS_DST_COLOR=_C('GL_ONE_MINUS_DST_COLOR',0x0307)
GL_ONE_MINUS_SRC_ALPHA=_C('GL_ONE_MINUS_SRC_ALPHA',0x0303)
GL_ONE_MINUS_SRC_COLOR=_C('GL_ONE_MINUS_SRC_COLOR',0x0301)
GL_OR=_C('GL_OR',0x1507)
GL_ORDER=_C('GL_ORDER',0x0A01)
GL_OR_INVERTED=_C('GL_OR_INVERTED',0x150D)
GL_OR_REVERSE=_C('GL_OR_REVERSE',0x150B)
GL_OUT_OF_MEMORY=_C('GL_OUT_OF_MEMORY',0x0505)
GL_PACK_ALIGNMENT=_C('GL_PACK_ALIGNMENT',0x0D05)
GL_PACK_LSB_FIRST=_C('GL_PACK_LSB_FIRST',0x0D01)
GL_PACK_ROW_LENGTH=_C('GL_PACK_ROW_LENGTH',0x0D02)
GL_PACK_SKIP_PIXELS=_C('GL_PACK_SKIP_PIXELS',0x0D04)
GL_PACK_SKIP_ROWS=_C('GL_PACK_SKIP_ROWS',0x0D03)
GL_PACK_SWAP_BYTES=_C('GL_PACK_SWAP_BYTES',0x0D00)
GL_PASS_THROUGH_TOKEN=_C('GL_PASS_THROUGH_TOKEN',0x0700)
GL_PERSPECTIVE_CORRECTION_HINT=_C('GL_PERSPECTIVE_CORRECTION_HINT',0x0C50)
GL_PIXEL_MAP_A_TO_A=_C('GL_PIXEL_MAP_A_TO_A',0x0C79)
GL_PIXEL_MAP_A_TO_A_SIZE=_C('GL_PIXEL_MAP_A_TO_A_SIZE',0x0CB9)
GL_PIXEL_MAP_B_TO_B=_C('GL_PIXEL_MAP_B_TO_B',0x0C78)
GL_PIXEL_MAP_B_TO_B_SIZE=_C('GL_PIXEL_MAP_B_TO_B_SIZE',0x0CB8)
GL_PIXEL_MAP_G_TO_G=_C('GL_PIXEL_MAP_G_TO_G',0x0C77)
GL_PIXEL_MAP_G_TO_G_SIZE=_C('GL_PIXEL_MAP_G_TO_G_SIZE',0x0CB7)
GL_PIXEL_MAP_I_TO_A=_C('GL_PIXEL_MAP_I_TO_A',0x0C75)
GL_PIXEL_MAP_I_TO_A_SIZE=_C('GL_PIXEL_MAP_I_TO_A_SIZE',0x0CB5)
GL_PIXEL_MAP_I_TO_B=_C('GL_PIXEL_MAP_I_TO_B',0x0C74)
GL_PIXEL_MAP_I_TO_B_SIZE=_C('GL_PIXEL_MAP_I_TO_B_SIZE',0x0CB4)
GL_PIXEL_MAP_I_TO_G=_C('GL_PIXEL_MAP_I_TO_G',0x0C73)
GL_PIXEL_MAP_I_TO_G_SIZE=_C('GL_PIXEL_MAP_I_TO_G_SIZE',0x0CB3)
GL_PIXEL_MAP_I_TO_I=_C('GL_PIXEL_MAP_I_TO_I',0x0C70)
GL_PIXEL_MAP_I_TO_I_SIZE=_C('GL_PIXEL_MAP_I_TO_I_SIZE',0x0CB0)
GL_PIXEL_MAP_I_TO_R=_C('GL_PIXEL_MAP_I_TO_R',0x0C72)
GL_PIXEL_MAP_I_TO_R_SIZE=_C('GL_PIXEL_MAP_I_TO_R_SIZE',0x0CB2)
GL_PIXEL_MAP_R_TO_R=_C('GL_PIXEL_MAP_R_TO_R',0x0C76)
GL_PIXEL_MAP_R_TO_R_SIZE=_C('GL_PIXEL_MAP_R_TO_R_SIZE',0x0CB6)
GL_PIXEL_MAP_S_TO_S=_C('GL_PIXEL_MAP_S_TO_S',0x0C71)
GL_PIXEL_MAP_S_TO_S_SIZE=_C('GL_PIXEL_MAP_S_TO_S_SIZE',0x0CB1)
GL_PIXEL_MODE_BIT=_C('GL_PIXEL_MODE_BIT',0x00000020)
GL_POINT=_C('GL_POINT',0x1B00)
GL_POINTS=_C('GL_POINTS',0x0000)
GL_POINT_BIT=_C('GL_POINT_BIT',0x00000002)
GL_POINT_SIZE=_C('GL_POINT_SIZE',0x0B11)
GL_POINT_SIZE_GRANULARITY=_C('GL_POINT_SIZE_GRANULARITY',0x0B13)
GL_POINT_SIZE_RANGE=_C('GL_POINT_SIZE_RANGE',0x0B12)
GL_POINT_SMOOTH=_C('GL_POINT_SMOOTH',0x0B10)
GL_POINT_SMOOTH_HINT=_C('GL_POINT_SMOOTH_HINT',0x0C51)
GL_POINT_TOKEN=_C('GL_POINT_TOKEN',0x0701)
GL_POLYGON=_C('GL_POLYGON',0x0009)
GL_POLYGON_BIT=_C('GL_POLYGON_BIT',0x00000008)
GL_POLYGON_MODE=_C('GL_POLYGON_MODE',0x0B40)
GL_POLYGON_SMOOTH=_C('GL_POLYGON_SMOOTH',0x0B41)
GL_POLYGON_SMOOTH_HINT=_C('GL_POLYGON_SMOOTH_HINT',0x0C53)
GL_POLYGON_STIPPLE=_C('GL_POLYGON_STIPPLE',0x0B42)
GL_POLYGON_STIPPLE_BIT=_C('GL_POLYGON_STIPPLE_BIT',0x00000010)
GL_POLYGON_TOKEN=_C('GL_POLYGON_TOKEN',0x0703)
GL_POSITION=_C('GL_POSITION',0x1203)
GL_PROJECTION=_C('GL_PROJECTION',0x1701)
GL_PROJECTION_MATRIX=_C('GL_PROJECTION_MATRIX',0x0BA7)
GL_PROJECTION_STACK_DEPTH=_C('GL_PROJECTION_STACK_DEPTH',0x0BA4)
GL_Q=_C('GL_Q',0x2003)
GL_QUADRATIC_ATTENUATION=_C('GL_QUADRATIC_ATTENUATION',0x1209)
GL_QUADS=_C('GL_QUADS',0x0007)
GL_QUAD_STRIP=_C('GL_QUAD_STRIP',0x0008)
GL_R=_C('GL_R',0x2002)
GL_READ_BUFFER=_C('GL_READ_BUFFER',0x0C02)
GL_RED=_C('GL_RED',0x1903)
GL_RED_BIAS=_C('GL_RED_BIAS',0x0D15)
GL_RED_BITS=_C('GL_RED_BITS',0x0D52)
GL_RED_SCALE=_C('GL_RED_SCALE',0x0D14)
GL_RENDER=_C('GL_RENDER',0x1C00)
GL_RENDERER=_C('GL_RENDERER',0x1F01)
GL_RENDER_MODE=_C('GL_RENDER_MODE',0x0C40)
GL_REPEAT=_C('GL_REPEAT',0x2901)
GL_REPLACE=_C('GL_REPLACE',0x1E01)
GL_RETURN=_C('GL_RETURN',0x0102)
GL_RGB=_C('GL_RGB',0x1907)
GL_RGBA=_C('GL_RGBA',0x1908)
GL_RGBA_MODE=_C('GL_RGBA_MODE',0x0C31)
GL_RIGHT=_C('GL_RIGHT',0x0407)
GL_S=_C('GL_S',0x2000)
GL_SCISSOR_BIT=_C('GL_SCISSOR_BIT',0x00080000)
GL_SCISSOR_BOX=_C('GL_SCISSOR_BOX',0x0C10)
GL_SCISSOR_TEST=_C('GL_SCISSOR_TEST',0x0C11)
GL_SELECT=_C('GL_SELECT',0x1C02)
GL_SET=_C('GL_SET',0x150F)
GL_SHADE_MODEL=_C('GL_SHADE_MODEL',0x0B54)
GL_SHININESS=_C('GL_SHININESS',0x1601)
GL_SHORT=_C('GL_SHORT',0x1402)
GL_SMOOTH=_C('GL_SMOOTH',0x1D01)
GL_SPECULAR=_C('GL_SPECULAR',0x1202)
GL_SPHERE_MAP=_C('GL_SPHERE_MAP',0x2402)
GL_SPOT_CUTOFF=_C('GL_SPOT_CUTOFF',0x1206)
GL_SPOT_DIRECTION=_C('GL_SPOT_DIRECTION',0x1204)
GL_SPOT_EXPONENT=_C('GL_SPOT_EXPONENT',0x1205)
GL_SRC_ALPHA=_C('GL_SRC_ALPHA',0x0302)
GL_SRC_ALPHA_SATURATE=_C('GL_SRC_ALPHA_SATURATE',0x0308)
GL_SRC_COLOR=_C('GL_SRC_COLOR',0x0300)
GL_STACK_OVERFLOW=_C('GL_STACK_OVERFLOW',0x0503)
GL_STACK_UNDERFLOW=_C('GL_STACK_UNDERFLOW',0x0504)
GL_STENCIL=_C('GL_STENCIL',0x1802)
GL_STENCIL_BITS=_C('GL_STENCIL_BITS',0x0D57)
GL_STENCIL_BUFFER_BIT=_C('GL_STENCIL_BUFFER_BIT',0x00000400)
GL_STENCIL_CLEAR_VALUE=_C('GL_STENCIL_CLEAR_VALUE',0x0B91)
GL_STENCIL_FAIL=_C('GL_STENCIL_FAIL',0x0B94)
GL_STENCIL_FUNC=_C('GL_STENCIL_FUNC',0x0B92)
GL_STENCIL_INDEX=_C('GL_STENCIL_INDEX',0x1901)
GL_STENCIL_PASS_DEPTH_FAIL=_C('GL_STENCIL_PASS_DEPTH_FAIL',0x0B95)
GL_STENCIL_PASS_DEPTH_PASS=_C('GL_STENCIL_PASS_DEPTH_PASS',0x0B96)
GL_STENCIL_REF=_C('GL_STENCIL_REF',0x0B97)
GL_STENCIL_TEST=_C('GL_STENCIL_TEST',0x0B90)
GL_STENCIL_VALUE_MASK=_C('GL_STENCIL_VALUE_MASK',0x0B93)
GL_STENCIL_WRITEMASK=_C('GL_STENCIL_WRITEMASK',0x0B98)
GL_STEREO=_C('GL_STEREO',0x0C33)
GL_SUBPIXEL_BITS=_C('GL_SUBPIXEL_BITS',0x0D50)
GL_T=_C('GL_T',0x2001)
GL_TEXTURE=_C('GL_TEXTURE',0x1702)
GL_TEXTURE_1D=_C('GL_TEXTURE_1D',0x0DE0)
GL_TEXTURE_2D=_C('GL_TEXTURE_2D',0x0DE1)
GL_TEXTURE_BIT=_C('GL_TEXTURE_BIT',0x00040000)
GL_TEXTURE_BORDER=_C('GL_TEXTURE_BORDER',0x1005)
GL_TEXTURE_BORDER_COLOR=_C('GL_TEXTURE_BORDER_COLOR',0x1004)
GL_TEXTURE_COMPONENTS=_C('GL_TEXTURE_COMPONENTS',0x1003)
GL_TEXTURE_ENV=_C('GL_TEXTURE_ENV',0x2300)
GL_TEXTURE_ENV_COLOR=_C('GL_TEXTURE_ENV_COLOR',0x2201)
GL_TEXTURE_ENV_MODE=_C('GL_TEXTURE_ENV_MODE',0x2200)
GL_TEXTURE_GEN_MODE=_C('GL_TEXTURE_GEN_MODE',0x2500)
GL_TEXTURE_GEN_Q=_C('GL_TEXTURE_GEN_Q',0x0C63)
GL_TEXTURE_GEN_R=_C('GL_TEXTURE_GEN_R',0x0C62)
GL_TEXTURE_GEN_S=_C('GL_TEXTURE_GEN_S',0x0C60)
GL_TEXTURE_GEN_T=_C('GL_TEXTURE_GEN_T',0x0C61)
GL_TEXTURE_HEIGHT=_C('GL_TEXTURE_HEIGHT',0x1001)
GL_TEXTURE_MAG_FILTER=_C('GL_TEXTURE_MAG_FILTER',0x2800)
GL_TEXTURE_MATRIX=_C('GL_TEXTURE_MATRIX',0x0BA8)
GL_TEXTURE_MIN_FILTER=_C('GL_TEXTURE_MIN_FILTER',0x2801)
GL_TEXTURE_STACK_DEPTH=_C('GL_TEXTURE_STACK_DEPTH',0x0BA5)
GL_TEXTURE_WIDTH=_C('GL_TEXTURE_WIDTH',0x1000)
GL_TEXTURE_WRAP_S=_C('GL_TEXTURE_WRAP_S',0x2802)
GL_TEXTURE_WRAP_T=_C('GL_TEXTURE_WRAP_T',0x2803)
GL_TRANSFORM_BIT=_C('GL_TRANSFORM_BIT',0x00001000)
GL_TRIANGLES=_C('GL_TRIANGLES',0x0004)
GL_TRIANGLE_FAN=_C('GL_TRIANGLE_FAN',0x0006)
GL_TRIANGLE_STRIP=_C('GL_TRIANGLE_STRIP',0x0005)
GL_TRUE=_C('GL_TRUE',1)
GL_UNPACK_ALIGNMENT=_C('GL_UNPACK_ALIGNMENT',0x0CF5)
GL_UNPACK_LSB_FIRST=_C('GL_UNPACK_LSB_FIRST',0x0CF1)
GL_UNPACK_ROW_LENGTH=_C('GL_UNPACK_ROW_LENGTH',0x0CF2)
GL_UNPACK_SKIP_PIXELS=_C('GL_UNPACK_SKIP_PIXELS',0x0CF4)
GL_UNPACK_SKIP_ROWS=_C('GL_UNPACK_SKIP_ROWS',0x0CF3)
GL_UNPACK_SWAP_BYTES=_C('GL_UNPACK_SWAP_BYTES',0x0CF0)
GL_UNSIGNED_BYTE=_C('GL_UNSIGNED_BYTE',0x1401)
GL_UNSIGNED_INT=_C('GL_UNSIGNED_INT',0x1405)
GL_UNSIGNED_SHORT=_C('GL_UNSIGNED_SHORT',0x1403)
GL_VENDOR=_C('GL_VENDOR',0x1F00)
GL_VERSION=_C('GL_VERSION',0x1F02)
GL_VIEWPORT=_C('GL_VIEWPORT',0x0BA2)
GL_VIEWPORT_BIT=_C('GL_VIEWPORT_BIT',0x00000800)
GL_XOR=_C('GL_XOR',0x1506)
GL_ZERO=_C('GL_ZERO',0)
GL_ZOOM_X=_C('GL_ZOOM_X',0x0D16)
GL_ZOOM_Y=_C('GL_ZOOM_Y',0x0D17)
@_f
@_p.types(None,_cs.GLenum,_cs.GLfloat)
def glAccum(op,value):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLfloat)
def glAlphaFunc(func,ref):pass
@_f
@_p.types(None,_cs.GLenum)
def glBegin(mode):pass
@_f
@_p.types(None,_cs.GLsizei,_cs.GLsizei,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat,arrays.GLubyteArray)
def glBitmap(width,height,xorig,yorig,xmove,ymove,bitmap):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum)
def glBlendFunc(sfactor,dfactor):pass
@_f
@_p.types(None,_cs.GLuint)
def glCallList(list):pass
@_f
@_p.types(None,_cs.GLsizei,_cs.GLenum,ctypes.c_void_p)
def glCallLists(n,type,lists):pass
@_f
@_p.types(None,_cs.GLbitfield)
def glClear(mask):pass
@_f
@_p.types(None,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat)
def glClearAccum(red,green,blue,alpha):pass
@_f
@_p.types(None,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat)
def glClearColor(red,green,blue,alpha):pass
@_f
@_p.types(None,_cs.GLdouble)
def glClearDepth(depth):pass
@_f
@_p.types(None,_cs.GLfloat)
def glClearIndex(c):pass
@_f
@_p.types(None,_cs.GLint)
def glClearStencil(s):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLdoubleArray)
def glClipPlane(plane,equation):pass
@_f
@_p.types(None,_cs.GLbyte,_cs.GLbyte,_cs.GLbyte)
def glColor3b(red,green,blue):pass
@_f
@_p.types(None,arrays.GLbyteArray)
def glColor3bv(v):pass
@_f
@_p.types(None,_cs.GLdouble,_cs.GLdouble,_cs.GLdouble)
def glColor3d(red,green,blue):pass
@_f
@_p.types(None,arrays.GLdoubleArray)
def glColor3dv(v):pass
@_f
@_p.types(None,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat)
def glColor3f(red,green,blue):pass
@_f
@_p.types(None,arrays.GLfloatArray)
def glColor3fv(v):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLint,_cs.GLint)
def glColor3i(red,green,blue):pass
@_f
@_p.types(None,arrays.GLintArray)
def glColor3iv(v):pass
@_f
@_p.types(None,_cs.GLshort,_cs.GLshort,_cs.GLshort)
def glColor3s(red,green,blue):pass
@_f
@_p.types(None,arrays.GLshortArray)
def glColor3sv(v):pass
@_f
@_p.types(None,_cs.GLubyte,_cs.GLubyte,_cs.GLubyte)
def glColor3ub(red,green,blue):pass
@_f
@_p.types(None,arrays.GLubyteArray)
def glColor3ubv(v):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLuint,_cs.GLuint)
def glColor3ui(red,green,blue):pass
@_f
@_p.types(None,arrays.GLuintArray)
def glColor3uiv(v):pass
@_f
@_p.types(None,_cs.GLushort,_cs.GLushort,_cs.GLushort)
def glColor3us(red,green,blue):pass
@_f
@_p.types(None,arrays.GLushortArray)
def glColor3usv(v):pass
@_f
@_p.types(None,_cs.GLbyte,_cs.GLbyte,_cs.GLbyte,_cs.GLbyte)
def glColor4b(red,green,blue,alpha):pass
@_f
@_p.types(None,arrays.GLbyteArray)
def glColor4bv(v):pass
@_f
@_p.types(None,_cs.GLdouble,_cs.GLdouble,_cs.GLdouble,_cs.GLdouble)
def glColor4d(red,green,blue,alpha):pass
@_f
@_p.types(None,arrays.GLdoubleArray)
def glColor4dv(v):pass
@_f
@_p.types(None,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat)
def glColor4f(red,green,blue,alpha):pass
@_f
@_p.types(None,arrays.GLfloatArray)
def glColor4fv(v):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLint)
def glColor4i(red,green,blue,alpha):pass
@_f
@_p.types(None,arrays.GLintArray)
def glColor4iv(v):pass
@_f
@_p.types(None,_cs.GLshort,_cs.GLshort,_cs.GLshort,_cs.GLshort)
def glColor4s(red,green,blue,alpha):pass
@_f
@_p.types(None,arrays.GLshortArray)
def glColor4sv(v):pass
@_f
@_p.types(None,_cs.GLubyte,_cs.GLubyte,_cs.GLubyte,_cs.GLubyte)
def glColor4ub(red,green,blue,alpha):pass
@_f
@_p.types(None,arrays.GLubyteArray)
def glColor4ubv(v):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLuint,_cs.GLuint,_cs.GLuint)
def glColor4ui(red,green,blue,alpha):pass
@_f
@_p.types(None,arrays.GLuintArray)
def glColor4uiv(v):pass
@_f
@_p.types(None,_cs.GLushort,_cs.GLushort,_cs.GLushort,_cs.GLushort)
def glColor4us(red,green,blue,alpha):pass
@_f
@_p.types(None,arrays.GLushortArray)
def glColor4usv(v):pass
@_f
@_p.types(None,_cs.GLboolean,_cs.GLboolean,_cs.GLboolean,_cs.GLboolean)
def glColorMask(red,green,blue,alpha):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum)
def glColorMaterial(face,mode):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLint,_cs.GLsizei,_cs.GLsizei,_cs.GLenum)
def glCopyPixels(x,y,width,height,type):pass
@_f
@_p.types(None,_cs.GLenum)
def glCullFace(mode):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLsizei)
def glDeleteLists(list,range):pass
@_f
@_p.types(None,_cs.GLenum)
def glDepthFunc(func):pass
@_f
@_p.types(None,_cs.GLboolean)
def glDepthMask(flag):pass
@_f
@_p.types(None,_cs.GLdouble,_cs.GLdouble)
def glDepthRange(n,f):pass
@_f
@_p.types(None,_cs.GLenum)
def glDisable(cap):pass
@_f
@_p.types(None,_cs.GLenum)
def glDrawBuffer(buf):pass
@_f
@_p.types(None,_cs.GLsizei,_cs.GLsizei,_cs.GLenum,_cs.GLenum,ctypes.c_void_p)
def glDrawPixels(width,height,format,type,pixels):pass
@_f
@_p.types(None,_cs.GLboolean)
def glEdgeFlag(flag):pass
@_f
@_p.types(None,arrays.GLbooleanArray)
def glEdgeFlagv(flag):pass
@_f
@_p.types(None,_cs.GLenum)
def glEnable(cap):pass
@_f
@_p.types(None,)
def glEnd():pass
@_f
@_p.types(None,)
def glEndList():pass
@_f
@_p.types(None,_cs.GLdouble)
def glEvalCoord1d(u):pass
@_f
@_p.types(None,arrays.GLdoubleArray)
def glEvalCoord1dv(u):pass
@_f
@_p.types(None,_cs.GLfloat)
def glEvalCoord1f(u):pass
@_f
@_p.types(None,arrays.GLfloatArray)
def glEvalCoord1fv(u):pass
@_f
@_p.types(None,_cs.GLdouble,_cs.GLdouble)
def glEvalCoord2d(u,v):pass
@_f
@_p.types(None,arrays.GLdoubleArray)
def glEvalCoord2dv(u):pass
@_f
@_p.types(None,_cs.GLfloat,_cs.GLfloat)
def glEvalCoord2f(u,v):pass
@_f
@_p.types(None,arrays.GLfloatArray)
def glEvalCoord2fv(u):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLint,_cs.GLint)
def glEvalMesh1(mode,i1,i2):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLint)
def glEvalMesh2(mode,i1,i2,j1,j2):pass
@_f
@_p.types(None,_cs.GLint)
def glEvalPoint1(i):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLint)
def glEvalPoint2(i,j):pass
@_f
@_p.types(None,_cs.GLsizei,_cs.GLenum,arrays.GLfloatArray)
def glFeedbackBuffer(size,type,buffer):pass
@_f
@_p.types(None,)
def glFinish():pass
@_f
@_p.types(None,)
def glFlush():pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLfloat)
def glFogf(pname,param):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLfloatArray)
def glFogfv(pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLint)
def glFogi(pname,param):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLintArray)
def glFogiv(pname,params):pass
@_f
@_p.types(None,_cs.GLenum)
def glFrontFace(mode):pass
@_f
@_p.types(None,_cs.GLdouble,_cs.GLdouble,_cs.GLdouble,_cs.GLdouble,_cs.GLdouble,_cs.GLdouble)
def glFrustum(left,right,bottom,top,zNear,zFar):pass
@_f
@_p.types(_cs.GLuint,_cs.GLsizei)
def glGenLists(range):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLbooleanArray)
def glGetBooleanv(pname,data):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLdoubleArray)
def glGetClipPlane(plane,equation):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLdoubleArray)
def glGetDoublev(pname,data):pass
@_f
@_p.types(_cs.GLenum,)
def glGetError():pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLfloatArray)
def glGetFloatv(pname,data):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLintArray)
def glGetIntegerv(pname,data):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLfloatArray)
def glGetLightfv(light,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLintArray)
def glGetLightiv(light,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLdoubleArray)
def glGetMapdv(target,query,v):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLfloatArray)
def glGetMapfv(target,query,v):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLintArray)
def glGetMapiv(target,query,v):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLfloatArray)
def glGetMaterialfv(face,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLintArray)
def glGetMaterialiv(face,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLfloatArray)
def glGetPixelMapfv(map,values):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLuintArray)
def glGetPixelMapuiv(map,values):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLushortArray)
def glGetPixelMapusv(map,values):pass
@_f
@_p.types(None,arrays.GLubyteArray)
def glGetPolygonStipple(mask):pass
@_f
@_p.types(arrays.GLubyteArray,_cs.GLenum)
def glGetString(name):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLfloatArray)
def glGetTexEnvfv(target,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLintArray)
def glGetTexEnviv(target,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLdoubleArray)
def glGetTexGendv(coord,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLfloatArray)
def glGetTexGenfv(coord,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLintArray)
def glGetTexGeniv(coord,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLint,_cs.GLenum,_cs.GLenum,ctypes.c_void_p)
def glGetTexImage(target,level,format,type,pixels):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLint,_cs.GLenum,arrays.GLfloatArray)
def glGetTexLevelParameterfv(target,level,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLint,_cs.GLenum,arrays.GLintArray)
def glGetTexLevelParameteriv(target,level,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLfloatArray)
def glGetTexParameterfv(target,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLintArray)
def glGetTexParameteriv(target,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum)
def glHint(target,mode):pass
@_f
@_p.types(None,_cs.GLuint)
def glIndexMask(mask):pass
@_f
@_p.types(None,_cs.GLdouble)
def glIndexd(c):pass
@_f
@_p.types(None,arrays.GLdoubleArray)
def glIndexdv(c):pass
@_f
@_p.types(None,_cs.GLfloat)
def glIndexf(c):pass
@_f
@_p.types(None,arrays.GLfloatArray)
def glIndexfv(c):pass
@_f
@_p.types(None,_cs.GLint)
def glIndexi(c):pass
@_f
@_p.types(None,arrays.GLintArray)
def glIndexiv(c):pass
@_f
@_p.types(None,_cs.GLshort)
def glIndexs(c):pass
@_f
@_p.types(None,arrays.GLshortArray)
def glIndexsv(c):pass
@_f
@_p.types(None,)
def glInitNames():pass
@_f
@_p.types(_cs.GLboolean,_cs.GLenum)
def glIsEnabled(cap):pass
@_f
@_p.types(_cs.GLboolean,_cs.GLuint)
def glIsList(list):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLfloat)
def glLightModelf(pname,param):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLfloatArray)
def glLightModelfv(pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLint)
def glLightModeli(pname,param):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLintArray)
def glLightModeliv(pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLfloat)
def glLightf(light,pname,param):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLfloatArray)
def glLightfv(light,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLint)
def glLighti(light,pname,param):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLintArray)
def glLightiv(light,pname,params):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLushort)
def glLineStipple(factor,pattern):pass
@_f
@_p.types(None,_cs.GLfloat)
def glLineWidth(width):pass
@_f
@_p.types(None,_cs.GLuint)
def glListBase(base):pass
@_f
@_p.types(None,)
def glLoadIdentity():pass
@_f
@_p.types(None,arrays.GLdoubleArray)
def glLoadMatrixd(m):pass
@_f
@_p.types(None,arrays.GLfloatArray)
def glLoadMatrixf(m):pass
@_f
@_p.types(None,_cs.GLuint)
def glLoadName(name):pass
@_f
@_p.types(None,_cs.GLenum)
def glLogicOp(opcode):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLdouble,_cs.GLdouble,_cs.GLint,_cs.GLint,arrays.GLdoubleArray)
def glMap1d(target,u1,u2,stride,order,points):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLfloat,_cs.GLfloat,_cs.GLint,_cs.GLint,arrays.GLfloatArray)
def glMap1f(target,u1,u2,stride,order,points):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLdouble,_cs.GLdouble,_cs.GLint,_cs.GLint,_cs.GLdouble,_cs.GLdouble,_cs.GLint,_cs.GLint,arrays.GLdoubleArray)
def glMap2d(target,u1,u2,ustride,uorder,v1,v2,vstride,vorder,points):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLfloat,_cs.GLfloat,_cs.GLint,_cs.GLint,_cs.GLfloat,_cs.GLfloat,_cs.GLint,_cs.GLint,arrays.GLfloatArray)
def glMap2f(target,u1,u2,ustride,uorder,v1,v2,vstride,vorder,points):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLdouble,_cs.GLdouble)
def glMapGrid1d(un,u1,u2):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLfloat,_cs.GLfloat)
def glMapGrid1f(un,u1,u2):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLdouble,_cs.GLdouble,_cs.GLint,_cs.GLdouble,_cs.GLdouble)
def glMapGrid2d(un,u1,u2,vn,v1,v2):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLfloat,_cs.GLfloat,_cs.GLint,_cs.GLfloat,_cs.GLfloat)
def glMapGrid2f(un,u1,u2,vn,v1,v2):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLfloat)
def glMaterialf(face,pname,param):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLfloatArray)
def glMaterialfv(face,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLint)
def glMateriali(face,pname,param):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLintArray)
def glMaterialiv(face,pname,params):pass
@_f
@_p.types(None,_cs.GLenum)
def glMatrixMode(mode):pass
@_f
@_p.types(None,arrays.GLdoubleArray)
def glMultMatrixd(m):pass
@_f
@_p.types(None,arrays.GLfloatArray)
def glMultMatrixf(m):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum)
def glNewList(list,mode):pass
@_f
@_p.types(None,_cs.GLbyte,_cs.GLbyte,_cs.GLbyte)
def glNormal3b(nx,ny,nz):pass
@_f
@_p.types(None,arrays.GLbyteArray)
def glNormal3bv(v):pass
@_f
@_p.types(None,_cs.GLdouble,_cs.GLdouble,_cs.GLdouble)
def glNormal3d(nx,ny,nz):pass
@_f
@_p.types(None,arrays.GLdoubleArray)
def glNormal3dv(v):pass
@_f
@_p.types(None,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat)
def glNormal3f(nx,ny,nz):pass
@_f
@_p.types(None,arrays.GLfloatArray)
def glNormal3fv(v):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLint,_cs.GLint)
def glNormal3i(nx,ny,nz):pass
@_f
@_p.types(None,arrays.GLintArray)
def glNormal3iv(v):pass
@_f
@_p.types(None,_cs.GLshort,_cs.GLshort,_cs.GLshort)
def glNormal3s(nx,ny,nz):pass
@_f
@_p.types(None,arrays.GLshortArray)
def glNormal3sv(v):pass
@_f
@_p.types(None,_cs.GLdouble,_cs.GLdouble,_cs.GLdouble,_cs.GLdouble,_cs.GLdouble,_cs.GLdouble)
def glOrtho(left,right,bottom,top,zNear,zFar):pass
@_f
@_p.types(None,_cs.GLfloat)
def glPassThrough(token):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLsizei,arrays.GLfloatArray)
def glPixelMapfv(map,mapsize,values):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLsizei,arrays.GLuintArray)
def glPixelMapuiv(map,mapsize,values):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLsizei,arrays.GLushortArray)
def glPixelMapusv(map,mapsize,values):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLfloat)
def glPixelStoref(pname,param):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLint)
def glPixelStorei(pname,param):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLfloat)
def glPixelTransferf(pname,param):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLint)
def glPixelTransferi(pname,param):pass
@_f
@_p.types(None,_cs.GLfloat,_cs.GLfloat)
def glPixelZoom(xfactor,yfactor):pass
@_f
@_p.types(None,_cs.GLfloat)
def glPointSize(size):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum)
def glPolygonMode(face,mode):pass
@_f
@_p.types(None,arrays.GLubyteArray)
def glPolygonStipple(mask):pass
@_f
@_p.types(None,)
def glPopAttrib():pass
@_f
@_p.types(None,)
def glPopMatrix():pass
@_f
@_p.types(None,)
def glPopName():pass
@_f
@_p.types(None,_cs.GLbitfield)
def glPushAttrib(mask):pass
@_f
@_p.types(None,)
def glPushMatrix():pass
@_f
@_p.types(None,_cs.GLuint)
def glPushName(name):pass
@_f
@_p.types(None,_cs.GLdouble,_cs.GLdouble)
def glRasterPos2d(x,y):pass
@_f
@_p.types(None,arrays.GLdoubleArray)
def glRasterPos2dv(v):pass
@_f
@_p.types(None,_cs.GLfloat,_cs.GLfloat)
def glRasterPos2f(x,y):pass
@_f
@_p.types(None,arrays.GLfloatArray)
def glRasterPos2fv(v):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLint)
def glRasterPos2i(x,y):pass
@_f
@_p.types(None,arrays.GLintArray)
def glRasterPos2iv(v):pass
@_f
@_p.types(None,_cs.GLshort,_cs.GLshort)
def glRasterPos2s(x,y):pass
@_f
@_p.types(None,arrays.GLshortArray)
def glRasterPos2sv(v):pass
@_f
@_p.types(None,_cs.GLdouble,_cs.GLdouble,_cs.GLdouble)
def glRasterPos3d(x,y,z):pass
@_f
@_p.types(None,arrays.GLdoubleArray)
def glRasterPos3dv(v):pass
@_f
@_p.types(None,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat)
def glRasterPos3f(x,y,z):pass
@_f
@_p.types(None,arrays.GLfloatArray)
def glRasterPos3fv(v):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLint,_cs.GLint)
def glRasterPos3i(x,y,z):pass
@_f
@_p.types(None,arrays.GLintArray)
def glRasterPos3iv(v):pass
@_f
@_p.types(None,_cs.GLshort,_cs.GLshort,_cs.GLshort)
def glRasterPos3s(x,y,z):pass
@_f
@_p.types(None,arrays.GLshortArray)
def glRasterPos3sv(v):pass
@_f
@_p.types(None,_cs.GLdouble,_cs.GLdouble,_cs.GLdouble,_cs.GLdouble)
def glRasterPos4d(x,y,z,w):pass
@_f
@_p.types(None,arrays.GLdoubleArray)
def glRasterPos4dv(v):pass
@_f
@_p.types(None,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat)
def glRasterPos4f(x,y,z,w):pass
@_f
@_p.types(None,arrays.GLfloatArray)
def glRasterPos4fv(v):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLint)
def glRasterPos4i(x,y,z,w):pass
@_f
@_p.types(None,arrays.GLintArray)
def glRasterPos4iv(v):pass
@_f
@_p.types(None,_cs.GLshort,_cs.GLshort,_cs.GLshort,_cs.GLshort)
def glRasterPos4s(x,y,z,w):pass
@_f
@_p.types(None,arrays.GLshortArray)
def glRasterPos4sv(v):pass
@_f
@_p.types(None,_cs.GLenum)
def glReadBuffer(src):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLint,_cs.GLsizei,_cs.GLsizei,_cs.GLenum,_cs.GLenum,ctypes.c_void_p)
def glReadPixels(x,y,width,height,format,type,pixels):pass
@_f
@_p.types(None,_cs.GLdouble,_cs.GLdouble,_cs.GLdouble,_cs.GLdouble)
def glRectd(x1,y1,x2,y2):pass
@_f
@_p.types(None,arrays.GLdoubleArray,arrays.GLdoubleArray)
def glRectdv(v1,v2):pass
@_f
@_p.types(None,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat)
def glRectf(x1,y1,x2,y2):pass
@_f
@_p.types(None,arrays.GLfloatArray,arrays.GLfloatArray)
def glRectfv(v1,v2):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLint)
def glRecti(x1,y1,x2,y2):pass
@_f
@_p.types(None,arrays.GLintArray,arrays.GLintArray)
def glRectiv(v1,v2):pass
@_f
@_p.types(None,_cs.GLshort,_cs.GLshort,_cs.GLshort,_cs.GLshort)
def glRects(x1,y1,x2,y2):pass
@_f
@_p.types(None,arrays.GLshortArray,arrays.GLshortArray)
def glRectsv(v1,v2):pass
@_f
@_p.types(_cs.GLint,_cs.GLenum)
def glRenderMode(mode):pass
@_f
@_p.types(None,_cs.GLdouble,_cs.GLdouble,_cs.GLdouble,_cs.GLdouble)
def glRotated(angle,x,y,z):pass
@_f
@_p.types(None,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat)
def glRotatef(angle,x,y,z):pass
@_f
@_p.types(None,_cs.GLdouble,_cs.GLdouble,_cs.GLdouble)
def glScaled(x,y,z):pass
@_f
@_p.types(None,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat)
def glScalef(x,y,z):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLint,_cs.GLsizei,_cs.GLsizei)
def glScissor(x,y,width,height):pass
@_f
@_p.types(None,_cs.GLsizei,arrays.GLuintArray)
def glSelectBuffer(size,buffer):pass
@_f
@_p.types(None,_cs.GLenum)
def glShadeModel(mode):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLint,_cs.GLuint)
def glStencilFunc(func,ref,mask):pass
@_f
@_p.types(None,_cs.GLuint)
def glStencilMask(mask):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLenum)
def glStencilOp(fail,zfail,zpass):pass
@_f
@_p.types(None,_cs.GLdouble)
def glTexCoord1d(s):pass
@_f
@_p.types(None,arrays.GLdoubleArray)
def glTexCoord1dv(v):pass
@_f
@_p.types(None,_cs.GLfloat)
def glTexCoord1f(s):pass
@_f
@_p.types(None,arrays.GLfloatArray)
def glTexCoord1fv(v):pass
@_f
@_p.types(None,_cs.GLint)
def glTexCoord1i(s):pass
@_f
@_p.types(None,arrays.GLintArray)
def glTexCoord1iv(v):pass
@_f
@_p.types(None,_cs.GLshort)
def glTexCoord1s(s):pass
@_f
@_p.types(None,arrays.GLshortArray)
def glTexCoord1sv(v):pass
@_f
@_p.types(None,_cs.GLdouble,_cs.GLdouble)
def glTexCoord2d(s,t):pass
@_f
@_p.types(None,arrays.GLdoubleArray)
def glTexCoord2dv(v):pass
@_f
@_p.types(None,_cs.GLfloat,_cs.GLfloat)
def glTexCoord2f(s,t):pass
@_f
@_p.types(None,arrays.GLfloatArray)
def glTexCoord2fv(v):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLint)
def glTexCoord2i(s,t):pass
@_f
@_p.types(None,arrays.GLintArray)
def glTexCoord2iv(v):pass
@_f
@_p.types(None,_cs.GLshort,_cs.GLshort)
def glTexCoord2s(s,t):pass
@_f
@_p.types(None,arrays.GLshortArray)
def glTexCoord2sv(v):pass
@_f
@_p.types(None,_cs.GLdouble,_cs.GLdouble,_cs.GLdouble)
def glTexCoord3d(s,t,r):pass
@_f
@_p.types(None,arrays.GLdoubleArray)
def glTexCoord3dv(v):pass
@_f
@_p.types(None,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat)
def glTexCoord3f(s,t,r):pass
@_f
@_p.types(None,arrays.GLfloatArray)
def glTexCoord3fv(v):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLint,_cs.GLint)
def glTexCoord3i(s,t,r):pass
@_f
@_p.types(None,arrays.GLintArray)
def glTexCoord3iv(v):pass
@_f
@_p.types(None,_cs.GLshort,_cs.GLshort,_cs.GLshort)
def glTexCoord3s(s,t,r):pass
@_f
@_p.types(None,arrays.GLshortArray)
def glTexCoord3sv(v):pass
@_f
@_p.types(None,_cs.GLdouble,_cs.GLdouble,_cs.GLdouble,_cs.GLdouble)
def glTexCoord4d(s,t,r,q):pass
@_f
@_p.types(None,arrays.GLdoubleArray)
def glTexCoord4dv(v):pass
@_f
@_p.types(None,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat)
def glTexCoord4f(s,t,r,q):pass
@_f
@_p.types(None,arrays.GLfloatArray)
def glTexCoord4fv(v):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLint)
def glTexCoord4i(s,t,r,q):pass
@_f
@_p.types(None,arrays.GLintArray)
def glTexCoord4iv(v):pass
@_f
@_p.types(None,_cs.GLshort,_cs.GLshort,_cs.GLshort,_cs.GLshort)
def glTexCoord4s(s,t,r,q):pass
@_f
@_p.types(None,arrays.GLshortArray)
def glTexCoord4sv(v):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLfloat)
def glTexEnvf(target,pname,param):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLfloatArray)
def glTexEnvfv(target,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLint)
def glTexEnvi(target,pname,param):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLintArray)
def glTexEnviv(target,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLdouble)
def glTexGend(coord,pname,param):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLdoubleArray)
def glTexGendv(coord,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLfloat)
def glTexGenf(coord,pname,param):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLfloatArray)
def glTexGenfv(coord,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLint)
def glTexGeni(coord,pname,param):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLintArray)
def glTexGeniv(coord,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLint,_cs.GLint,_cs.GLsizei,_cs.GLint,_cs.GLenum,_cs.GLenum,ctypes.c_void_p)
def glTexImage1D(target,level,internalformat,width,border,format,type,pixels):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLint,_cs.GLint,_cs.GLsizei,_cs.GLsizei,_cs.GLint,_cs.GLenum,_cs.GLenum,ctypes.c_void_p)
def glTexImage2D(target,level,internalformat,width,height,border,format,type,pixels):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLfloat)
def glTexParameterf(target,pname,param):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLfloatArray)
def glTexParameterfv(target,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLint)
def glTexParameteri(target,pname,param):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLintArray)
def glTexParameteriv(target,pname,params):pass
@_f
@_p.types(None,_cs.GLdouble,_cs.GLdouble,_cs.GLdouble)
def glTranslated(x,y,z):pass
@_f
@_p.types(None,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat)
def glTranslatef(x,y,z):pass
@_f
@_p.types(None,_cs.GLdouble,_cs.GLdouble)
def glVertex2d(x,y):pass
@_f
@_p.types(None,arrays.GLdoubleArray)
def glVertex2dv(v):pass
@_f
@_p.types(None,_cs.GLfloat,_cs.GLfloat)
def glVertex2f(x,y):pass
@_f
@_p.types(None,arrays.GLfloatArray)
def glVertex2fv(v):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLint)
def glVertex2i(x,y):pass
@_f
@_p.types(None,arrays.GLintArray)
def glVertex2iv(v):pass
@_f
@_p.types(None,_cs.GLshort,_cs.GLshort)
def glVertex2s(x,y):pass
@_f
@_p.types(None,arrays.GLshortArray)
def glVertex2sv(v):pass
@_f
@_p.types(None,_cs.GLdouble,_cs.GLdouble,_cs.GLdouble)
def glVertex3d(x,y,z):pass
@_f
@_p.types(None,arrays.GLdoubleArray)
def glVertex3dv(v):pass
@_f
@_p.types(None,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat)
def glVertex3f(x,y,z):pass
@_f
@_p.types(None,arrays.GLfloatArray)
def glVertex3fv(v):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLint,_cs.GLint)
def glVertex3i(x,y,z):pass
@_f
@_p.types(None,arrays.GLintArray)
def glVertex3iv(v):pass
@_f
@_p.types(None,_cs.GLshort,_cs.GLshort,_cs.GLshort)
def glVertex3s(x,y,z):pass
@_f
@_p.types(None,arrays.GLshortArray)
def glVertex3sv(v):pass
@_f
@_p.types(None,_cs.GLdouble,_cs.GLdouble,_cs.GLdouble,_cs.GLdouble)
def glVertex4d(x,y,z,w):pass
@_f
@_p.types(None,arrays.GLdoubleArray)
def glVertex4dv(v):pass
@_f
@_p.types(None,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat)
def glVertex4f(x,y,z,w):pass
@_f
@_p.types(None,arrays.GLfloatArray)
def glVertex4fv(v):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLint)
def glVertex4i(x,y,z,w):pass
@_f
@_p.types(None,arrays.GLintArray)
def glVertex4iv(v):pass
@_f
@_p.types(None,_cs.GLshort,_cs.GLshort,_cs.GLshort,_cs.GLshort)
def glVertex4s(x,y,z,w):pass
@_f
@_p.types(None,arrays.GLshortArray)
def glVertex4sv(v):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLint,_cs.GLsizei,_cs.GLsizei)
def glViewport(x,y,width,height):pass



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.EGL import _types as _cs
# End users want this...
from OpenGL.raw.EGL._types import *
from OpenGL.raw.EGL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'EGL_ANDROID_native_fence_sync'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.EGL,'EGL_ANDROID_native_fence_sync',error_checker=_errors._error_checker)
EGL_NO_NATIVE_FENCE_FD_ANDROID=_C('EGL_NO_NATIVE_FENCE_FD_ANDROID',-1)
EGL_SYNC_NATIVE_FENCE_ANDROID=_C('EGL_SYNC_NATIVE_FENCE_ANDROID',0x3144)
EGL_SYNC_NATIVE_FENCE_FD_ANDROID=_C('EGL_SYNC_NATIVE_FENCE_FD_ANDROID',0x3145)
EGL_SYNC_NATIVE_FENCE_SIGNALED_ANDROID=_C('EGL_SYNC_NATIVE_FENCE_SIGNALED_ANDROID',0x3146)
@_f
@_p.types(_cs.EGLint,_cs.EGLDisplay,_cs.EGLSyncKHR)
def eglDupNativeFenceFDANDROID(dpy,sync):pass



'''OpenGL extension OES.texture_mirrored_repeat

This module customises the behaviour of the 
OpenGL.raw.GLES1.OES.texture_mirrored_repeat to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension extends the set of texture wrap modes to
	include a mode (GL_MIRRORED_REPEAT) that effectively uses a texture
	map twice as large at the original image in which the additional half,
	for each coordinate, of the new image is a mirror image of the original
	image.
	
	This new mode relaxes the need to generate images whose opposite edges
	match by using the original image to generate a matching "mirror image".

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/OES/texture_mirrored_repeat.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLES1 import _types, _glgets
from OpenGL.raw.GLES1.OES.texture_mirrored_repeat import *
from OpenGL.raw.GLES1.OES.texture_mirrored_repeat import _EXTENSION_NAME

def glInitTextureMirroredRepeatOES():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension NV.texture_expand_normal

This module customises the behaviour of the 
OpenGL.raw.GL.NV.texture_expand_normal to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension provides a remapping mode where unsigned texture
	components (in the range [0,1]) can be treated as though they
	contained signed data (in the range [-1,+1]).  This allows
	applications to easily encode signed data into unsigned texture
	formats.
	
	The functionality of this extension is nearly identical to the
	EXPAND_NORMAL_NV remapping mode provided in the NV_register_combiners
	extension, although it applies even if register combiners are used.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/NV/texture_expand_normal.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.NV.texture_expand_normal import *
from OpenGL.raw.GL.NV.texture_expand_normal import _EXTENSION_NAME

def glInitTextureExpandNormalNV():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


"""Implementation of the special "glGet" functions

For comparison, here's what a straightforward implementation looks like:

    def glGetDoublev( pname ):
        "Natural writing of glGetDoublev using standard ctypes"
        output = c_double*sizes.get( pname )
        result = output()
        result = platform.PLATFORM.GL.glGetDoublev( pname, byref(result) )
        return Numeric.array( result )
"""
from OpenGL.GL.VERSION import GL_1_1 as _simple
import ctypes
GLenum = ctypes.c_uint
GLsize = GLsizei = ctypes.c_int

__all__ = (
    'glGetString',
)

glGetString = _simple.glGetString
glGetString.restype = ctypes.c_char_p
glGetString.__doc__ = """glGetString( constant ) -> Current string value"""



'''OpenGL extension ARB.sparse_texture2

This module customises the behaviour of the 
OpenGL.raw.GL.ARB.sparse_texture2 to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension builds on the ARB_sparse_texture extension, providing the
	following new functionality:
	
	  * New built-in GLSL texture lookup and image load functions are provided
	    that return information on whether the texels accessed for the texture
	    lookup accessed uncommitted texture memory.
	
	  * New built-in GLSL texture lookup functions are provided that specify a
	    minimum level of detail to use for lookups where the level of detail
	    is computed automatically.  This allows shaders to avoid accessing
	    unpopulated portions of high-resolution levels of detail when it knows
	    that the memory accessed is unpopulated, either from a priori
	    knowledge or from feedback provided by the return value of previously
	    executed "sparse" texture lookup functions.
	
	  * Reads of uncommitted texture memory will act as though such memory
	    were filled with zeroes; previously, the values returned by reads were
	    undefined.
	
	  * Standard implementation-independent virtual page sizes for internal
	    formats required to be supported with sparse textures. These standard
	    sizes can be requested by leaving VIRTUAL_PAGE_SIZE_INDEX_ARB at its
	    initial value (0).
	
	  * Support for creating sparse multisample and multisample array textures
	    is added.  However, the virtual page sizes for such textures remain
	    fully implementation-dependent.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/ARB/sparse_texture2.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.ARB.sparse_texture2 import *
from OpenGL.raw.GL.ARB.sparse_texture2 import _EXTENSION_NAME

def glInitSparseTexture2ARB():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension EXT.multiview_texture_multisample

This module customises the behaviour of the 
OpenGL.raw.GL.EXT.multiview_texture_multisample to provide a more 
Python-friendly API

Overview (from the spec)
	
	OVR_multiview introduced multiview rendering to OpenGL and OpenGL ES.
	
	This extension removes one of the limitations of the OVR_multiview 
	extension by allowing the use of multisample textures during multiview rendering.
	
	This is one of two extensions that allow multisampling when using 
	OVR_multiview. Each supports one of the two different approaches to 
	multisampling in OpenGL and OpenGL ES:
	
	    Core OpenGL and OpenGL ES 3.1+ have explicit support for multisample 
	    texture types, such as TEXTURE_2D_MULTISAMPLE. Applications can access 
	    the values of individual samples and can explicitly "resolve" the 
	    samples of each pixel down to a single color.
	
	    The extension EXT_multisampled_render_to_texture provides support for 
	    multisampled rendering to non-multisample texture types, such as 
	    TEXTURE_2D. The individual samples for each pixel are maintained 
	    internally by the implementation and can not be accessed directly 
	    by applications. These samples are eventually resolved implicitly to 
	    a single color for each pixel.
	
	This extension supports the first multisampling style with multiview 
	rendering; the OVR_multiview_multisampled_render_to_texture extension 
	supports the second style. Note that support for one of these multiview 
	extensions does not imply support for the other.
	

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/EXT/multiview_texture_multisample.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.EXT.multiview_texture_multisample import *
from OpenGL.raw.GL.EXT.multiview_texture_multisample import _EXTENSION_NAME

def glInitMultiviewTextureMultisampleEXT():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GLES2 import _types as _cs
# End users want this...
from OpenGL.raw.GLES2._types import *
from OpenGL.raw.GLES2 import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GLES2_NV_clip_space_w_scaling'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GLES2,'GLES2_NV_clip_space_w_scaling',error_checker=_errors._error_checker)
GL_VIEWPORT_POSITION_W_SCALE_NV=_C('GL_VIEWPORT_POSITION_W_SCALE_NV',0x937C)
GL_VIEWPORT_POSITION_W_SCALE_X_COEFF_NV=_C('GL_VIEWPORT_POSITION_W_SCALE_X_COEFF_NV',0x937D)
GL_VIEWPORT_POSITION_W_SCALE_Y_COEFF_NV=_C('GL_VIEWPORT_POSITION_W_SCALE_Y_COEFF_NV',0x937E)
@_f
@_p.types(None,_cs.GLuint,_cs.GLfloat,_cs.GLfloat)
def glViewportPositionWScaleNV(index,xcoeff,ycoeff):pass



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GLSC2 import _types as _cs
# End users want this...
from OpenGL.raw.GLSC2._types import *
from OpenGL.raw.GLSC2 import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GLSC2_OES_standard_derivatives'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GLSC2,'GLSC2_OES_standard_derivatives',error_checker=_errors._error_checker)
GL_FRAGMENT_SHADER_DERIVATIVE_HINT_OES=_C('GL_FRAGMENT_SHADER_DERIVATIVE_HINT_OES',0x8B8B)




'''OpenGL extension NV.conservative_raster_pre_snap_triangles

This module customises the behaviour of the 
OpenGL.raw.GLES2.NV.conservative_raster_pre_snap_triangles to provide a more 
Python-friendly API

Overview (from the spec)
	
	When CONSERVATIVE_RASTERIZATION_NV is enabled, the fragments generated for
	a primitive are conservative with respect to the primitive after snapping
	to sub-pixel grid.  This extension provides a new mode of rasterization
	for triangles where the fragments generated are conservative with respect
	to the primitive at infinite precision before vertex snapping.
	
	When the conservative raster mode is set to CONSERVATIVE_RASTER_MODE_PRE_-
	SNAP_TRIANGLES, triangles are rasterized more conservatively, and may
	generate fragments not generated when the mode is CONSERVATIVE_RASTER_MODE_-
	POST_SNAP (default). In particular it may generate fragments for pixels
	covered by triangles with zero area, or for pixels that are adjacent to
	but not covered by any triangle. This modified behavior may be useful in
	compensating for rounding errors caused by snapping vertex positions to a
	sub-pixel grid during rasterization.  It's possible that a non-degenerate
	triangle becomes degenerate due to snapping.  It's additionally possible
	that rounding errors in computing the position of a vertex or from
	snapping may cause a primitive that would cover a pixel at infinite
	precision to fail to cover the pixel post-snap.  Rasterizing such
	primitives more conservatively may be useful for "binning" algorithms
	described in NV_conservative_raster.
	

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/NV/conservative_raster_pre_snap_triangles.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLES2 import _types, _glgets
from OpenGL.raw.GLES2.NV.conservative_raster_pre_snap_triangles import *
from OpenGL.raw.GLES2.NV.conservative_raster_pre_snap_triangles import _EXTENSION_NAME

def glInitConservativeRasterPreSnapTrianglesNV():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


"""Buffer based Numpy plugin (not used)

This API is no more useful than the direct Numpy version, as Numpy already 
gives us the details we need *when using the accelerator module* at a low 
level, with very fast access.  When using the non-accelerated version the 
ctypes version *might* show some performance benefits, but it's not going 
to be fast no matter what we do without C-level code.
"""
REGISTRY_NAME = 'numpybuffers'
import operator
try:
    import numpy
except ImportError as err:
    raise ImportError( """No numpy module present: %s"""%(err))
from OpenGL.arrays import buffers
from OpenGL.raw.GL import _types 
from OpenGL.raw.GL.VERSION import GL_1_1
from OpenGL import constant, error
class NumpyHandler( buffers.BufferHandler ):
    @classmethod
    def zeros( cls, dims, typeCode ):
        """Return Numpy array of zeros in given size"""
        return numpy.zeros( dims, GL_TYPE_TO_ARRAY_MAPPING[typeCode])
    
    @classmethod
    def asArray( cls, value, typeCode=None ):
        """Convert given value to an array value of given typeCode"""
        return super(NumpyHandler,cls).asArray( cls.contiguous(value,typeCode), typeCode )
    @classmethod
    def contiguous( cls, source, typeCode=None ):
        """Get contiguous array from source

        source -- numpy Python array (or compatible object)
            for use as the data source.  If this is not a contiguous
            array of the given typeCode, a copy will be made,
            otherwise will just be returned unchanged.
        typeCode -- optional 1-character typeCode specifier for
            the numpy.array function.

        All gl*Pointer calls should use contiguous arrays, as non-
        contiguous arrays will be re-copied on every rendering pass.
        Although this doesn't raise an error, it does tend to slow
        down rendering.
        """
        typeCode = GL_TYPE_TO_ARRAY_MAPPING[ typeCode ]
        try:
            contiguous = source.flags.contiguous
        except AttributeError as err:
            if typeCode:
                return numpy.ascontiguousarray( source, typeCode )
            else:
                return numpy.ascontiguousarray( source )
        else:
            if contiguous and (typeCode is None or typeCode==source.dtype.char):
                return source
            elif (contiguous and cls.ERROR_ON_COPY):
                from OpenGL import error
                raise error.CopyError(
                    """Array of type %r passed, required array of type %r""",
                    source.dtype.char, typeCode,
                )
            else:
                # We have to do astype to avoid errors about unsafe conversions
                # XXX Confirm that this will *always* create a new contiguous array
                # XXX Guard against wacky conversion types like uint to float, where
                # we really don't want to have the C-level conversion occur.
                # XXX ascontiguousarray is apparently now available in numpy!
                if cls.ERROR_ON_COPY:
                    from OpenGL import error
                    raise error.CopyError(
                        """Non-contiguous array passed""",
                        source,
                    )
                if typeCode is None:
                    typeCode = source.dtype.char
                return numpy.ascontiguousarray( source, typeCode )
try:
    numpy.array( [1], 's' )
    SHORT_TYPE = 's'
except TypeError as err:
    SHORT_TYPE = 'h'
    USHORT_TYPE = 'H'

def lookupDtype( char ):
    return numpy.zeros( (1,), dtype=char ).dtype

ARRAY_TO_GL_TYPE_MAPPING = {
    lookupDtype('d'): GL_1_1.GL_DOUBLE,
    lookupDtype('f'): GL_1_1.GL_FLOAT,
    lookupDtype('i'): GL_1_1.GL_INT,
    lookupDtype(SHORT_TYPE): GL_1_1.GL_SHORT,
    lookupDtype(USHORT_TYPE): GL_1_1.GL_UNSIGNED_SHORT,
    lookupDtype('B'): GL_1_1.GL_UNSIGNED_BYTE,
    lookupDtype('c'): GL_1_1.GL_UNSIGNED_BYTE,
    lookupDtype('b'): GL_1_1.GL_BYTE,
    lookupDtype('I'): GL_1_1.GL_UNSIGNED_INT,
    #lookupDtype('P'), GL_1_1.GL_VOID_P, # normally duplicates another type (e.g. 'I')
    None: None,
}
GL_TYPE_TO_ARRAY_MAPPING = {
    GL_1_1.GL_DOUBLE: lookupDtype('d'),
    GL_1_1.GL_FLOAT:lookupDtype('f'),
    GL_1_1.GL_INT: lookupDtype('i'),
    GL_1_1.GL_BYTE: lookupDtype('b'),
    GL_1_1.GL_SHORT: lookupDtype(SHORT_TYPE),
    GL_1_1.GL_UNSIGNED_INT: lookupDtype('I'),
    GL_1_1.GL_UNSIGNED_BYTE: lookupDtype('B'),
    GL_1_1.GL_UNSIGNED_SHORT: lookupDtype(USHORT_TYPE),
    _types.GL_VOID_P: lookupDtype('P'),
    None: None,
    'f': lookupDtype('f'),
    'd': lookupDtype('d'),
    'i': lookupDtype('i'),
    'I': lookupDtype('I'),
    'h': lookupDtype('h'),
    'H': lookupDtype('H'),
    'b': lookupDtype('b'),
    'B': lookupDtype('B'),
    's': lookupDtype('B'),
}



'''OpenGL extension MESA.program_binary_formats

This module customises the behaviour of the 
OpenGL.raw.GLES2.MESA.program_binary_formats to provide a more 
Python-friendly API

Overview (from the spec)
	
	The get_program_binary exensions require a GLenum binaryFormat.
	This extension documents that format for use with Mesa.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/MESA/program_binary_formats.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLES2 import _types, _glgets
from OpenGL.raw.GLES2.MESA.program_binary_formats import *
from OpenGL.raw.GLES2.MESA.program_binary_formats import _EXTENSION_NAME

def glInitProgramBinaryFormatsMESA():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension AMD.gpu_shader_half_float

This module customises the behaviour of the 
OpenGL.raw.GL.AMD.gpu_shader_half_float to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension was developed based on the NV_gpu_shader5 extension to
	allow implementations supporting half float in shader and expose the
	feature without the additional requirements that are present in
	NV_gpu_shader5.
	
	The extension introduces the following features for all shader types:
	
	  * support for half float scalar, vector and matrix data types in shader;
	
	  * new built-in functions to pack and unpack half float types into a
	    32-bit integer vector;
	
	  * half float support for all existing single float built-in functions,
	    including angle functions, exponential functions, common functions,
	    geometric functions, matrix functions and etc.;
	
	This extension is designed to be a functional superset of the half-precision
	floating-point support from NV_gpu_shader5 and to keep source code compatible
	with that, thus the new procedures, functions, and tokens are identical to
	those found in that extension.
	

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/AMD/gpu_shader_half_float.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.AMD.gpu_shader_half_float import *
from OpenGL.raw.GL.AMD.gpu_shader_half_float import _EXTENSION_NAME

def glInitGpuShaderHalfFloatAMD():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension EXT.raster_multisample

This module customises the behaviour of the 
OpenGL.raw.GL.EXT.raster_multisample to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension allows rendering to a non-multisample color buffer while
	rasterizing with more than one sample. The result of rasterization
	(coverage) is available in the gl_SampleMaskIn[] fragment shader input,
	multisample rasterization is enabled for all primitives, and several per-
	fragment operations operate at the raster sample rate.
	
	When using the functionality provided by this extension, depth, stencil,
	and depth bounds tests must be disabled, and a multisample draw
	framebuffer must not be used.
	
	A fragment's "coverage", or "effective raster samples" is considered to
	have "N bits" (as opposed to "one bit" corresponding to the single color
	sample) through the fragment shader, in the sample mask output, through
	the multisample fragment operations and occlusion query, until the coverage
	is finally "reduced" to a single bit in a new "Coverage Reduction" stage
	that occurs before blending.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/EXT/raster_multisample.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.EXT.raster_multisample import *
from OpenGL.raw.GL.EXT.raster_multisample import _EXTENSION_NAME

def glInitRasterMultisampleEXT():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension EXT.win32_keyed_mutex

This module customises the behaviour of the 
OpenGL.raw.GL.EXT.win32_keyed_mutex to provide a more 
Python-friendly API

Overview (from the spec)
	
	Direct3D image objects may have a built-in synchronization primitive
	associated with them that can be used to synchronize access to their
	contents across process and API boundaries.  This extension provides
	access to that synchronization primitive via two new commands that
	operate on GL memory objects.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/EXT/win32_keyed_mutex.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.EXT.win32_keyed_mutex import *
from OpenGL.raw.GL.EXT.win32_keyed_mutex import _EXTENSION_NAME

def glInitWin32KeyedMutexEXT():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension QCOM.extended_get2

This module customises the behaviour of the 
OpenGL.raw.GLES1.QCOM.extended_get2 to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension enables instrumenting the driver for debugging of OpenGL ES 
	applications.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/QCOM/extended_get2.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLES1 import _types, _glgets
from OpenGL.raw.GLES1.QCOM.extended_get2 import *
from OpenGL.raw.GLES1.QCOM.extended_get2 import _EXTENSION_NAME

def glInitExtendedGet2QCOM():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

# INPUT glExtGetShadersQCOM.shaders size not checked against maxShaders
glExtGetShadersQCOM=wrapper.wrapper(glExtGetShadersQCOM).setInputArraySize(
    'numShaders', 1
).setInputArraySize(
    'shaders', None
)
# INPUT glExtGetProgramsQCOM.programs size not checked against maxPrograms
glExtGetProgramsQCOM=wrapper.wrapper(glExtGetProgramsQCOM).setInputArraySize(
    'numPrograms', 1
).setInputArraySize(
    'programs', None
)
### END AUTOGENERATED SECTION


'''OpenGL extension QCOM.binning_control

This module customises the behaviour of the 
OpenGL.raw.GLES2.QCOM.binning_control to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension adds some new hints to give more control to application
	developers over the driver's binning algorithm.
	
	Only change this state right before changing rendertargets or right after
	a swap or there will be a large performance penalty.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/QCOM/binning_control.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLES2 import _types, _glgets
from OpenGL.raw.GLES2.QCOM.binning_control import *
from OpenGL.raw.GLES2.QCOM.binning_control import _EXTENSION_NAME

def glInitBinningControlQCOM():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_NV_texture_shader3'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_NV_texture_shader3',error_checker=_errors._error_checker)
GL_DEPENDENT_HILO_TEXTURE_2D_NV=_C('GL_DEPENDENT_HILO_TEXTURE_2D_NV',0x8858)
GL_DEPENDENT_RGB_TEXTURE_3D_NV=_C('GL_DEPENDENT_RGB_TEXTURE_3D_NV',0x8859)
GL_DEPENDENT_RGB_TEXTURE_CUBE_MAP_NV=_C('GL_DEPENDENT_RGB_TEXTURE_CUBE_MAP_NV',0x885A)
GL_DOT_PRODUCT_AFFINE_DEPTH_REPLACE_NV=_C('GL_DOT_PRODUCT_AFFINE_DEPTH_REPLACE_NV',0x885D)
GL_DOT_PRODUCT_PASS_THROUGH_NV=_C('GL_DOT_PRODUCT_PASS_THROUGH_NV',0x885B)
GL_DOT_PRODUCT_TEXTURE_1D_NV=_C('GL_DOT_PRODUCT_TEXTURE_1D_NV',0x885C)
GL_FORCE_BLUE_TO_ONE_NV=_C('GL_FORCE_BLUE_TO_ONE_NV',0x8860)
GL_HILO8_NV=_C('GL_HILO8_NV',0x885E)
GL_OFFSET_HILO_PROJECTIVE_TEXTURE_2D_NV=_C('GL_OFFSET_HILO_PROJECTIVE_TEXTURE_2D_NV',0x8856)
GL_OFFSET_HILO_PROJECTIVE_TEXTURE_RECTANGLE_NV=_C('GL_OFFSET_HILO_PROJECTIVE_TEXTURE_RECTANGLE_NV',0x8857)
GL_OFFSET_HILO_TEXTURE_2D_NV=_C('GL_OFFSET_HILO_TEXTURE_2D_NV',0x8854)
GL_OFFSET_HILO_TEXTURE_RECTANGLE_NV=_C('GL_OFFSET_HILO_TEXTURE_RECTANGLE_NV',0x8855)
GL_OFFSET_PROJECTIVE_TEXTURE_2D_NV=_C('GL_OFFSET_PROJECTIVE_TEXTURE_2D_NV',0x8850)
GL_OFFSET_PROJECTIVE_TEXTURE_2D_SCALE_NV=_C('GL_OFFSET_PROJECTIVE_TEXTURE_2D_SCALE_NV',0x8851)
GL_OFFSET_PROJECTIVE_TEXTURE_RECTANGLE_NV=_C('GL_OFFSET_PROJECTIVE_TEXTURE_RECTANGLE_NV',0x8852)
GL_OFFSET_PROJECTIVE_TEXTURE_RECTANGLE_SCALE_NV=_C('GL_OFFSET_PROJECTIVE_TEXTURE_RECTANGLE_SCALE_NV',0x8853)
GL_SIGNED_HILO8_NV=_C('GL_SIGNED_HILO8_NV',0x885F)




'''OpenGL extension AMD.blend_minmax_factor

This module customises the behaviour of the 
OpenGL.raw.GL.AMD.blend_minmax_factor to provide a more 
Python-friendly API

Overview (from the spec)
	
	The EXT_blend_minmax extension extended the GL's blending functionality
	to allow the blending equation to be specified by the application. That
	extension introduced the MIN_EXT and MAX_EXT blend equations, which caused the
	result of the blend equation to become the minimum or maximum of the source
	color and destination color, respectively.
	
	The MIN_EXT and MAX_EXT blend equations, however, do not include the source
	or destination blend factors in the arguments to the min and max functions.
	This extension provides two new blend equations that produce the minimum
	or maximum of the products of the source color and source factor, and the
	destination color and destination factor.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/AMD/blend_minmax_factor.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.AMD.blend_minmax_factor import *
from OpenGL.raw.GL.AMD.blend_minmax_factor import _EXTENSION_NAME

def glInitBlendMinmaxFactorAMD():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension NV.shader_noperspective_interpolation

This module customises the behaviour of the 
OpenGL.raw.GLES2.NV.shader_noperspective_interpolation to provide a more 
Python-friendly API

Overview (from the spec)
	
	In OpenGL 3.0 and later, and in other APIs, there are three types of
	interpolation qualifiers that are available for fragment shader inputs:
	flat, smooth, and noperspective.  The 'flat' qualifier indicates that no
	interpolation should be used. This is mandatory for integer-type
	variables. The 'smooth' qualifier indicates that interpolation should be
	performed in a perspective0correct manner. This is the default for
	floating-point type variables.  The 'noperspective' qualifier indicates
	that interpolation should be performed linearly in screen space.
	
	While perspective-correct (smooth) and non-interpolated (flat) are the
	two types of interpolation that most commonly used, there are important
	use cases for linear (noperspective) interpolation.  In particular, in
	some work loads where screen-space aligned geometry is common, the use of
	linear interpolation can result in performance and/or power improvements.
	
	The smooth and flat interpolation qualifiers are already supported in
	OpenGL ES 3.0 and later. This extension adds support for noperspective
	interpolation to OpenGL ES.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/NV/shader_noperspective_interpolation.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLES2 import _types, _glgets
from OpenGL.raw.GLES2.NV.shader_noperspective_interpolation import *
from OpenGL.raw.GLES2.NV.shader_noperspective_interpolation import _EXTENSION_NAME

def glInitShaderNoperspectiveInterpolationNV():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


#! /usr/bin/env python
"""Test for a buffer-protocol-based access mechanism

Will *only* work for Python 2.6+, and pretty much just works for strings
under 2.6 (in terms of the common object types).
"""
import sys,operator,logging,traceback
from OpenGL.arrays import _buffers
from OpenGL.raw.GL import _types
#from OpenGL.raw.GL.VERSION import GL_1_1
from OpenGL.arrays import formathandler
from OpenGL import _configflags
from OpenGL import acceleratesupport
_log = logging.getLogger( __name__ )
try:
    reduce 
except NameError as err:
    from functools import reduce

MemoryviewHandler = BufferHandler = None
if sys.version_info[:2] > (2,6):
    # Only Python 2.7+ has memoryview support, and the accelerate module 
    # requires memoryviews to be able to pass around the buffer structures
    if acceleratesupport.ACCELERATE_AVAILABLE:
        try:
            from OpenGL_accelerate.buffers_formathandler import MemoryviewHandler
        except ImportError as err:
            traceback.print_exc()
            _log.warning(
                "Unable to load buffers_formathandler accelerator from OpenGL_accelerate"
            )
        else:
            BufferHandler = MemoryviewHandler
if not BufferHandler:
    class BufferHandler( formathandler.FormatHandler ):
        """Buffer-protocol data-type handler for OpenGL"""
        isOutput=False
        ERROR_ON_COPY = _configflags.ERROR_ON_COPY
        if sys.version_info[0] >= 3:
            @classmethod
            def from_param( cls, value, typeCode=None ):
                if not isinstance( value, _buffers.Py_buffer ):
                    value = cls.asArray( value )
                    #raise TypeError( """Can't convert value to py-buffer in from_param""" )
                # TODO: only do this IFF value.internal is None
                return _types.GLvoidp( value.buf )
#                return value
        else:
            @classmethod
            def from_param( cls, value, typeCode=None ):
                if not isinstance( value, _buffers.Py_buffer ):
                    value = cls.asArray( value )
                    #raise TypeError( """Can't convert value to py-buffer in from_param""" )
                return value.buf
        def dataPointer( value ):
            if not isinstance( value, _buffers.Py_buffer ):
                value = _buffers.Py_buffer.from_object( value )
            return value.buf
        dataPointer = staticmethod( dataPointer )
        @classmethod
        def zeros( cls, dims, typeCode=None ):
            """Currently don't allow strings as output types!"""
            raise NotImplementedError( "Generic buffer type does not have output capability" )
            return cls.asArray( bytearray( b'\000'*reduce(operator.mul,dims)*BYTE_SIZES[typeCode] ) )
        @classmethod
        def ones( cls, dims, typeCode=None ):
            """Currently don't allow strings as output types!"""
            raise NotImplementedError( """Have not implemented ones for buffer type""" )
        @classmethod
        def arrayToGLType( cls, value ):
            """Given a value, guess OpenGL type of the corresponding pointer"""
            format = value.format 
            if format in ARRAY_TO_GL_TYPE_MAPPING:
                return ARRAY_TO_GL_TYPE_MAPPING[format]
            raise TypeError( 'Unknown format: %r'%(format,))
        @classmethod
        def arraySize( cls, value, typeCode = None ):
            """Given a data-value, calculate ravelled size for the array"""
            return value.len // value.itemsize
        @classmethod
        def arrayByteCount( cls, value, typeCode = None ):
            """Given a data-value, calculate number of bytes required to represent"""
            return value.len
        @classmethod 
        def unitSize( cls, value, default=None ):
            return value.dims[-1]
        @classmethod
        def asArray( cls, value, typeCode=None ):
            """Convert given value to an array value of given typeCode"""
            buf = _buffers.Py_buffer.from_object( value )
            return buf
        @classmethod
        def dimensions( cls, value, typeCode=None ):
            """Determine dimensions of the passed array value (if possible)"""
            return value.dims

ARRAY_TO_GL_TYPE_MAPPING = _buffers.ARRAY_TO_GL_TYPE_MAPPING
BYTE_SIZES = _buffers.BYTE_SIZES



'''OpenGL extension NV.path_rendering_shared_edge

This module customises the behaviour of the 
OpenGL.raw.GL.NV.path_rendering_shared_edge to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension introduces a new path command modifier to the
	NV_path_rendering extension to indicate that a path command represents an
	edge (either straight or curved) that is shared with another path.
	
	When used in conjunction with NV_framebuffer_mixed_samples, a shared edge
	(or a whole path including shared edges) will use modified rasterization
	rules in order to ensure that groups of raster samples associated with a
	given coverage sample will all produce consistent coverage results, in
	order to avoid artifacts described further in the issues section at the
	end of this document.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/NV/path_rendering_shared_edge.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.NV.path_rendering_shared_edge import *
from OpenGL.raw.GL.NV.path_rendering_shared_edge import _EXTENSION_NAME

def glInitPathRenderingSharedEdgeNV():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension VERSION.GL_1_0

This module customises the behaviour of the 
OpenGL.raw.GL.VERSION.GL_1_0 to provide a more 
Python-friendly API

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/VERSION/GL_1_0.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.VERSION.GL_1_0 import *
from OpenGL.raw.GL.VERSION.GL_1_0 import _EXTENSION_NAME

def glInitGl10VERSION():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

# INPUT glTexParameterfv.params size not checked against 'pname'
glTexParameterfv=wrapper.wrapper(glTexParameterfv).setInputArraySize(
    'params', None
)
# INPUT glTexParameteriv.params size not checked against 'pname'
glTexParameteriv=wrapper.wrapper(glTexParameteriv).setInputArraySize(
    'params', None
)
# INPUT glTexImage1D.pixels size not checked against 'format,type,width'
glTexImage1D=wrapper.wrapper(glTexImage1D).setInputArraySize(
    'pixels', None
)
# INPUT glTexImage2D.pixels size not checked against 'format,type,width,height'
glTexImage2D=wrapper.wrapper(glTexImage2D).setInputArraySize(
    'pixels', None
)
# OUTPUT glReadPixels.pixels COMPSIZE(format, type, width, height) 
glGetBooleanv=wrapper.wrapper(glGetBooleanv).setOutput(
    'data',size=_glgets._glget_size_mapping,pnameArg='pname',orPassIn=True
)
glGetDoublev=wrapper.wrapper(glGetDoublev).setOutput(
    'data',size=_glgets._glget_size_mapping,pnameArg='pname',orPassIn=True
)
glGetFloatv=wrapper.wrapper(glGetFloatv).setOutput(
    'data',size=_glgets._glget_size_mapping,pnameArg='pname',orPassIn=True
)
glGetIntegerv=wrapper.wrapper(glGetIntegerv).setOutput(
    'data',size=_glgets._glget_size_mapping,pnameArg='pname',orPassIn=True
)
# OUTPUT glGetTexImage.pixels COMPSIZE(target, level, format, type) 
glGetTexParameterfv=wrapper.wrapper(glGetTexParameterfv).setOutput(
    'params',size=_glgets._glget_size_mapping,pnameArg='pname',orPassIn=True
)
glGetTexParameteriv=wrapper.wrapper(glGetTexParameteriv).setOutput(
    'params',size=_glgets._glget_size_mapping,pnameArg='pname',orPassIn=True
)
glGetTexLevelParameterfv=wrapper.wrapper(glGetTexLevelParameterfv).setOutput(
    'params',size=_glgets._glget_size_mapping,pnameArg='pname',orPassIn=True
)
glGetTexLevelParameteriv=wrapper.wrapper(glGetTexLevelParameteriv).setOutput(
    'params',size=_glgets._glget_size_mapping,pnameArg='pname',orPassIn=True
)
# INPUT glCallLists.lists size not checked against 'n,type'
glCallLists=wrapper.wrapper(glCallLists).setInputArraySize(
    'lists', None
)
# INPUT glBitmap.bitmap size not checked against 'width,height'
glBitmap=wrapper.wrapper(glBitmap).setInputArraySize(
    'bitmap', None
)
glColor3bv=wrapper.wrapper(glColor3bv).setInputArraySize(
    'v', 3
)
glColor3dv=wrapper.wrapper(glColor3dv).setInputArraySize(
    'v', 3
)
glColor3fv=wrapper.wrapper(glColor3fv).setInputArraySize(
    'v', 3
)
glColor3iv=wrapper.wrapper(glColor3iv).setInputArraySize(
    'v', 3
)
glColor3sv=wrapper.wrapper(glColor3sv).setInputArraySize(
    'v', 3
)
glColor3ubv=wrapper.wrapper(glColor3ubv).setInputArraySize(
    'v', 3
)
glColor3uiv=wrapper.wrapper(glColor3uiv).setInputArraySize(
    'v', 3
)
glColor3usv=wrapper.wrapper(glColor3usv).setInputArraySize(
    'v', 3
)
glColor4bv=wrapper.wrapper(glColor4bv).setInputArraySize(
    'v', 4
)
glColor4dv=wrapper.wrapper(glColor4dv).setInputArraySize(
    'v', 4
)
glColor4fv=wrapper.wrapper(glColor4fv).setInputArraySize(
    'v', 4
)
glColor4iv=wrapper.wrapper(glColor4iv).setInputArraySize(
    'v', 4
)
glColor4sv=wrapper.wrapper(glColor4sv).setInputArraySize(
    'v', 4
)
glColor4ubv=wrapper.wrapper(glColor4ubv).setInputArraySize(
    'v', 4
)
glColor4uiv=wrapper.wrapper(glColor4uiv).setInputArraySize(
    'v', 4
)
glColor4usv=wrapper.wrapper(glColor4usv).setInputArraySize(
    'v', 4
)
glEdgeFlagv=wrapper.wrapper(glEdgeFlagv).setInputArraySize(
    'flag', 1
)
glIndexdv=wrapper.wrapper(glIndexdv).setInputArraySize(
    'c', 1
)
glIndexfv=wrapper.wrapper(glIndexfv).setInputArraySize(
    'c', 1
)
glIndexiv=wrapper.wrapper(glIndexiv).setInputArraySize(
    'c', 1
)
glIndexsv=wrapper.wrapper(glIndexsv).setInputArraySize(
    'c', 1
)
glNormal3bv=wrapper.wrapper(glNormal3bv).setInputArraySize(
    'v', 3
)
glNormal3dv=wrapper.wrapper(glNormal3dv).setInputArraySize(
    'v', 3
)
glNormal3fv=wrapper.wrapper(glNormal3fv).setInputArraySize(
    'v', 3
)
glNormal3iv=wrapper.wrapper(glNormal3iv).setInputArraySize(
    'v', 3
)
glNormal3sv=wrapper.wrapper(glNormal3sv).setInputArraySize(
    'v', 3
)
glRasterPos2dv=wrapper.wrapper(glRasterPos2dv).setInputArraySize(
    'v', 2
)
glRasterPos2fv=wrapper.wrapper(glRasterPos2fv).setInputArraySize(
    'v', 2
)
glRasterPos2iv=wrapper.wrapper(glRasterPos2iv).setInputArraySize(
    'v', 2
)
glRasterPos2sv=wrapper.wrapper(glRasterPos2sv).setInputArraySize(
    'v', 2
)
glRasterPos3dv=wrapper.wrapper(glRasterPos3dv).setInputArraySize(
    'v', 3
)
glRasterPos3fv=wrapper.wrapper(glRasterPos3fv).setInputArraySize(
    'v', 3
)
glRasterPos3iv=wrapper.wrapper(glRasterPos3iv).setInputArraySize(
    'v', 3
)
glRasterPos3sv=wrapper.wrapper(glRasterPos3sv).setInputArraySize(
    'v', 3
)
glRasterPos4dv=wrapper.wrapper(glRasterPos4dv).setInputArraySize(
    'v', 4
)
glRasterPos4fv=wrapper.wrapper(glRasterPos4fv).setInputArraySize(
    'v', 4
)
glRasterPos4iv=wrapper.wrapper(glRasterPos4iv).setInputArraySize(
    'v', 4
)
glRasterPos4sv=wrapper.wrapper(glRasterPos4sv).setInputArraySize(
    'v', 4
)
glRectdv=wrapper.wrapper(glRectdv).setInputArraySize(
    'v1', 2
).setInputArraySize(
    'v2', 2
)
glRectfv=wrapper.wrapper(glRectfv).setInputArraySize(
    'v1', 2
).setInputArraySize(
    'v2', 2
)
glRectiv=wrapper.wrapper(glRectiv).setInputArraySize(
    'v1', 2
).setInputArraySize(
    'v2', 2
)
glRectsv=wrapper.wrapper(glRectsv).setInputArraySize(
    'v1', 2
).setInputArraySize(
    'v2', 2
)
glTexCoord1dv=wrapper.wrapper(glTexCoord1dv).setInputArraySize(
    'v', 1
)
glTexCoord1fv=wrapper.wrapper(glTexCoord1fv).setInputArraySize(
    'v', 1
)
glTexCoord1iv=wrapper.wrapper(glTexCoord1iv).setInputArraySize(
    'v', 1
)
glTexCoord1sv=wrapper.wrapper(glTexCoord1sv).setInputArraySize(
    'v', 1
)
glTexCoord2dv=wrapper.wrapper(glTexCoord2dv).setInputArraySize(
    'v', 2
)
glTexCoord2fv=wrapper.wrapper(glTexCoord2fv).setInputArraySize(
    'v', 2
)
glTexCoord2iv=wrapper.wrapper(glTexCoord2iv).setInputArraySize(
    'v', 2
)
glTexCoord2sv=wrapper.wrapper(glTexCoord2sv).setInputArraySize(
    'v', 2
)
glTexCoord3dv=wrapper.wrapper(glTexCoord3dv).setInputArraySize(
    'v', 3
)
glTexCoord3fv=wrapper.wrapper(glTexCoord3fv).setInputArraySize(
    'v', 3
)
glTexCoord3iv=wrapper.wrapper(glTexCoord3iv).setInputArraySize(
    'v', 3
)
glTexCoord3sv=wrapper.wrapper(glTexCoord3sv).setInputArraySize(
    'v', 3
)
glTexCoord4dv=wrapper.wrapper(glTexCoord4dv).setInputArraySize(
    'v', 4
)
glTexCoord4fv=wrapper.wrapper(glTexCoord4fv).setInputArraySize(
    'v', 4
)
glTexCoord4iv=wrapper.wrapper(glTexCoord4iv).setInputArraySize(
    'v', 4
)
glTexCoord4sv=wrapper.wrapper(glTexCoord4sv).setInputArraySize(
    'v', 4
)
glVertex2dv=wrapper.wrapper(glVertex2dv).setInputArraySize(
    'v', 2
)
glVertex2fv=wrapper.wrapper(glVertex2fv).setInputArraySize(
    'v', 2
)
glVertex2iv=wrapper.wrapper(glVertex2iv).setInputArraySize(
    'v', 2
)
glVertex2sv=wrapper.wrapper(glVertex2sv).setInputArraySize(
    'v', 2
)
glVertex3dv=wrapper.wrapper(glVertex3dv).setInputArraySize(
    'v', 3
)
glVertex3fv=wrapper.wrapper(glVertex3fv).setInputArraySize(
    'v', 3
)
glVertex3iv=wrapper.wrapper(glVertex3iv).setInputArraySize(
    'v', 3
)
glVertex3sv=wrapper.wrapper(glVertex3sv).setInputArraySize(
    'v', 3
)
glVertex4dv=wrapper.wrapper(glVertex4dv).setInputArraySize(
    'v', 4
)
glVertex4fv=wrapper.wrapper(glVertex4fv).setInputArraySize(
    'v', 4
)
glVertex4iv=wrapper.wrapper(glVertex4iv).setInputArraySize(
    'v', 4
)
glVertex4sv=wrapper.wrapper(glVertex4sv).setInputArraySize(
    'v', 4
)
glClipPlane=wrapper.wrapper(glClipPlane).setInputArraySize(
    'equation', 4
)
# INPUT glFogfv.params size not checked against 'pname'
glFogfv=wrapper.wrapper(glFogfv).setInputArraySize(
    'params', None
)
# INPUT glFogiv.params size not checked against 'pname'
glFogiv=wrapper.wrapper(glFogiv).setInputArraySize(
    'params', None
)
# INPUT glLightfv.params size not checked against 'pname'
glLightfv=wrapper.wrapper(glLightfv).setInputArraySize(
    'params', None
)
# INPUT glLightiv.params size not checked against 'pname'
glLightiv=wrapper.wrapper(glLightiv).setInputArraySize(
    'params', None
)
# INPUT glLightModelfv.params size not checked against 'pname'
glLightModelfv=wrapper.wrapper(glLightModelfv).setInputArraySize(
    'params', None
)
# INPUT glLightModeliv.params size not checked against 'pname'
glLightModeliv=wrapper.wrapper(glLightModeliv).setInputArraySize(
    'params', None
)
# INPUT glMaterialfv.params size not checked against 'pname'
glMaterialfv=wrapper.wrapper(glMaterialfv).setInputArraySize(
    'params', None
)
# INPUT glMaterialiv.params size not checked against 'pname'
glMaterialiv=wrapper.wrapper(glMaterialiv).setInputArraySize(
    'params', None
)
# INPUT glPolygonStipple.mask size not checked against ''
glPolygonStipple=wrapper.wrapper(glPolygonStipple).setInputArraySize(
    'mask', None
)
# INPUT glTexEnvfv.params size not checked against 'pname'
glTexEnvfv=wrapper.wrapper(glTexEnvfv).setInputArraySize(
    'params', None
)
# INPUT glTexEnviv.params size not checked against 'pname'
glTexEnviv=wrapper.wrapper(glTexEnviv).setInputArraySize(
    'params', None
)
# INPUT glTexGendv.params size not checked against 'pname'
glTexGendv=wrapper.wrapper(glTexGendv).setInputArraySize(
    'params', None
)
# INPUT glTexGenfv.params size not checked against 'pname'
glTexGenfv=wrapper.wrapper(glTexGenfv).setInputArraySize(
    'params', None
)
# INPUT glTexGeniv.params size not checked against 'pname'
glTexGeniv=wrapper.wrapper(glTexGeniv).setInputArraySize(
    'params', None
)
glFeedbackBuffer=wrapper.wrapper(glFeedbackBuffer).setOutput(
    'buffer',size=lambda x:(x,),pnameArg='size',orPassIn=True
)
glSelectBuffer=wrapper.wrapper(glSelectBuffer).setOutput(
    'buffer',size=lambda x:(x,),pnameArg='size',orPassIn=True
)
# INPUT glMap1d.points size not checked against 'target,stride,order'
glMap1d=wrapper.wrapper(glMap1d).setInputArraySize(
    'points', None
)
# INPUT glMap1f.points size not checked against 'target,stride,order'
glMap1f=wrapper.wrapper(glMap1f).setInputArraySize(
    'points', None
)
# INPUT glMap2d.points size not checked against 'target,ustride,uorder,vstride,vorder'
glMap2d=wrapper.wrapper(glMap2d).setInputArraySize(
    'points', None
)
# INPUT glMap2f.points size not checked against 'target,ustride,uorder,vstride,vorder'
glMap2f=wrapper.wrapper(glMap2f).setInputArraySize(
    'points', None
)
glEvalCoord1dv=wrapper.wrapper(glEvalCoord1dv).setInputArraySize(
    'u', 1
)
glEvalCoord1fv=wrapper.wrapper(glEvalCoord1fv).setInputArraySize(
    'u', 1
)
glEvalCoord2dv=wrapper.wrapper(glEvalCoord2dv).setInputArraySize(
    'u', 2
)
glEvalCoord2fv=wrapper.wrapper(glEvalCoord2fv).setInputArraySize(
    'u', 2
)
# INPUT glPixelMapfv.values size not checked against mapsize
glPixelMapfv=wrapper.wrapper(glPixelMapfv).setInputArraySize(
    'values', None
)
# INPUT glPixelMapuiv.values size not checked against mapsize
glPixelMapuiv=wrapper.wrapper(glPixelMapuiv).setInputArraySize(
    'values', None
)
# INPUT glPixelMapusv.values size not checked against mapsize
glPixelMapusv=wrapper.wrapper(glPixelMapusv).setInputArraySize(
    'values', None
)
# INPUT glDrawPixels.pixels size not checked against 'format,type,width,height'
glDrawPixels=wrapper.wrapper(glDrawPixels).setInputArraySize(
    'pixels', None
)
glGetClipPlane=wrapper.wrapper(glGetClipPlane).setOutput(
    'equation',size=(4,),orPassIn=True
)
glGetLightfv=wrapper.wrapper(glGetLightfv).setOutput(
    'params',size=_glgets._glget_size_mapping,pnameArg='pname',orPassIn=True
)
glGetLightiv=wrapper.wrapper(glGetLightiv).setOutput(
    'params',size=_glgets._glget_size_mapping,pnameArg='pname',orPassIn=True
)
# OUTPUT glGetMapdv.v COMPSIZE(target, query) 
# OUTPUT glGetMapfv.v COMPSIZE(target, query) 
# OUTPUT glGetMapiv.v COMPSIZE(target, query) 
glGetMaterialfv=wrapper.wrapper(glGetMaterialfv).setOutput(
    'params',size=_glgets._glget_size_mapping,pnameArg='pname',orPassIn=True
)
glGetMaterialiv=wrapper.wrapper(glGetMaterialiv).setOutput(
    'params',size=_glgets._glget_size_mapping,pnameArg='pname',orPassIn=True
)
glGetPixelMapfv=wrapper.wrapper(glGetPixelMapfv).setOutput(
    'values',size=_glgets._glget_size_mapping,pnameArg='map',orPassIn=True
)
glGetPixelMapuiv=wrapper.wrapper(glGetPixelMapuiv).setOutput(
    'values',size=_glgets._glget_size_mapping,pnameArg='map',orPassIn=True
)
glGetPixelMapusv=wrapper.wrapper(glGetPixelMapusv).setOutput(
    'values',size=_glgets._glget_size_mapping,pnameArg='map',orPassIn=True
)
glGetPolygonStipple=wrapper.wrapper(glGetPolygonStipple).setOutput(
    'mask',size=lambda x:(x,),pnameArg='128.0',orPassIn=True
)
glGetTexEnvfv=wrapper.wrapper(glGetTexEnvfv).setOutput(
    'params',size=_glgets._glget_size_mapping,pnameArg='pname',orPassIn=True
)
glGetTexEnviv=wrapper.wrapper(glGetTexEnviv).setOutput(
    'params',size=_glgets._glget_size_mapping,pnameArg='pname',orPassIn=True
)
glGetTexGendv=wrapper.wrapper(glGetTexGendv).setOutput(
    'params',size=_glgets._glget_size_mapping,pnameArg='pname',orPassIn=True
)
glGetTexGenfv=wrapper.wrapper(glGetTexGenfv).setOutput(
    'params',size=_glgets._glget_size_mapping,pnameArg='pname',orPassIn=True
)
glGetTexGeniv=wrapper.wrapper(glGetTexGeniv).setOutput(
    'params',size=_glgets._glget_size_mapping,pnameArg='pname',orPassIn=True
)
glLoadMatrixf=wrapper.wrapper(glLoadMatrixf).setInputArraySize(
    'm', 16
)
glLoadMatrixd=wrapper.wrapper(glLoadMatrixd).setInputArraySize(
    'm', 16
)
glMultMatrixf=wrapper.wrapper(glMultMatrixf).setInputArraySize(
    'm', 16
)
glMultMatrixd=wrapper.wrapper(glMultMatrixd).setInputArraySize(
    'm', 16
)
### END AUTOGENERATED SECTION


'''OpenGL extension NV.read_buffer

This module customises the behaviour of the 
OpenGL.raw.GLES2.NV.read_buffer to provide a more 
Python-friendly API

Overview (from the spec)
	
	Unextended OpenGL ES 2.0 only supports using ReadPixels to read from
	the default color buffer of the currently-bound framebuffer.
	However, it is useful for debugging to be able to read from
	non-default color buffers.  Particularly, when the NV_draw_buffers
	extension is supported, each framebuffer may contain multiple color
	buffers. This extension provides a mechanism to select which color
	buffer to read from.
	
	This document describes two extensions to allow an implementation to
	support a subset of the total functionality.
	
	The NV_read_buffer extension adds the command ReadBufferNV, which is
	used to select which color buffer of the currently-bound framebuffer
	to use as the source for subsequent calls to ReadPixels,
	CopyTexImage2D, and CopyTexSubImage2D. If the system-provided
	framebuffer is bound, then ReadBufferNV accepts value BACK. If a
	user-created FBO is bound, then ReadBufferNV accepts COLOR_ATTACHMENT0.
	Additionally, if the NV_draw_buffers extension is supported,
	ReadBufferNV accepts COLOR_ATTACHMENTn_NV (n is 0 to 15).
	
	The NV_read_buffer_front extension requires NV_read_buffer and adds
	the ability to select the system-provided FRONT color buffer as the
	source for read operations when the system-provided framebuffer is
	bound and contains both a front and back buffer.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/NV/read_buffer.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLES2 import _types, _glgets
from OpenGL.raw.GLES2.NV.read_buffer import *
from OpenGL.raw.GLES2.NV.read_buffer import _EXTENSION_NAME

def glInitReadBufferNV():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_EXT_semaphore'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_EXT_semaphore',error_checker=_errors._error_checker)
GL_DEVICE_UUID_EXT=_C('GL_DEVICE_UUID_EXT',0x9597)
GL_DRIVER_UUID_EXT=_C('GL_DRIVER_UUID_EXT',0x9598)
GL_LAYOUT_COLOR_ATTACHMENT_EXT=_C('GL_LAYOUT_COLOR_ATTACHMENT_EXT',0x958E)
GL_LAYOUT_DEPTH_ATTACHMENT_STENCIL_READ_ONLY_EXT=_C('GL_LAYOUT_DEPTH_ATTACHMENT_STENCIL_READ_ONLY_EXT',0x9531)
GL_LAYOUT_DEPTH_READ_ONLY_STENCIL_ATTACHMENT_EXT=_C('GL_LAYOUT_DEPTH_READ_ONLY_STENCIL_ATTACHMENT_EXT',0x9530)
GL_LAYOUT_DEPTH_STENCIL_ATTACHMENT_EXT=_C('GL_LAYOUT_DEPTH_STENCIL_ATTACHMENT_EXT',0x958F)
GL_LAYOUT_DEPTH_STENCIL_READ_ONLY_EXT=_C('GL_LAYOUT_DEPTH_STENCIL_READ_ONLY_EXT',0x9590)
GL_LAYOUT_GENERAL_EXT=_C('GL_LAYOUT_GENERAL_EXT',0x958D)
GL_LAYOUT_SHADER_READ_ONLY_EXT=_C('GL_LAYOUT_SHADER_READ_ONLY_EXT',0x9591)
GL_LAYOUT_TRANSFER_DST_EXT=_C('GL_LAYOUT_TRANSFER_DST_EXT',0x9593)
GL_LAYOUT_TRANSFER_SRC_EXT=_C('GL_LAYOUT_TRANSFER_SRC_EXT',0x9592)
GL_NUM_DEVICE_UUIDS_EXT=_C('GL_NUM_DEVICE_UUIDS_EXT',0x9596)
GL_UUID_SIZE_EXT=_C('GL_UUID_SIZE_EXT',16)
@_f
@_p.types(None,_cs.GLsizei,arrays.GLuintArray)
def glDeleteSemaphoresEXT(n,semaphores):pass
@_f
@_p.types(None,_cs.GLsizei,arrays.GLuintArray)
def glGenSemaphoresEXT(n,semaphores):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,arrays.GLuint64Array)
def glGetSemaphoreParameterui64vEXT(semaphore,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint,arrays.GLubyteArray)
def glGetUnsignedBytei_vEXT(target,index,data):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLubyteArray)
def glGetUnsignedBytevEXT(pname,data):pass
@_f
@_p.types(_cs.GLboolean,_cs.GLuint)
def glIsSemaphoreEXT(semaphore):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,arrays.GLuint64Array)
def glSemaphoreParameterui64vEXT(semaphore,pname,params):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLuint,arrays.GLuintArray,_cs.GLuint,arrays.GLuintArray,arrays.GLuintArray)
def glSignalSemaphoreEXT(semaphore,numBufferBarriers,buffers,numTextureBarriers,textures,dstLayouts):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLuint,arrays.GLuintArray,_cs.GLuint,arrays.GLuintArray,arrays.GLuintArray)
def glWaitSemaphoreEXT(semaphore,numBufferBarriers,buffers,numTextureBarriers,textures,srcLayouts):pass
